### 1.1.14 确保关键文件、目录权限最小化

**级别：** 要求

**适用版本：** 全部

**规则说明：** 

按照权限最小化要求，系统中的关键文件，特别是包含有敏感信息的文件，必须设置正确的最小的访问权限，只能有相应权限的用户可以访问，目录也是同样要求。文件或目录权限配置不正确，可能导致包含敏感数据的文件信息泄露，例如访问权限设置大于等于644，任何用户都可以访问，甚至篡改；只有root用户可以执行的程序，但却设置了755的权限，导致任何用户都可以执行，引入提权风险。

常见的需要做访问权限控制的文件或目录类型有：

* 可执行文件（二进制文件、脚本），存放可执行文件的目录。如果权限配置不当可能会导致提权攻击。

* 配置文件、密钥文件、日志文件、存储有敏感信息的数据文件、系统运行时产生的临时文件、静态文件等。这些文件中可能会含有敏感数据、隐私数据，如果权限配置不当会增加信息泄露的风险。

权限控制基本原则如下：

| 文件类型                           | 设置值           |
| ---------------------------------- | ---------------- |
| 用户主目录                         | 750（rwxr-x---） |
| 程序文件(含脚本文件、库文件等)     | 550（r-xr-x---） |
| 程序文件目录                       | 550（r-xr-x---） |
| 配置文件                           | 640（rw-r-----） |
| 配置文件目录                       | 750（rwxr-x---） |
| 日志文件(记录完毕或者已经归档)     | 440（r--r-----） |
| 日志文件(正在记录)                 | 640（rw-r-----） |
| 日志文件目录                       | 750（rwxr-x---） |
| Debug文件                          | 640（rw-r-----） |
| Debug文件目录                      | 750（rwxr-x---） |
| 临时文件目录                       | 750（rwxr-x---） |
| 维护升级文件目录                   | 770（rwxrwx---） |
| 业务数据文件                       | 640（rw-r-----） |
| 业务数据文件目录                   | 750（rwxr-x---） |
| 密钥组件、私钥、证书、密文文件目录 | 700（rwx—----）  |
| 密钥组件、私钥、证书、加密密文     | 600（rw-------） |
| 加解密接口、加解密脚本             | 500（r-x------） |

鉴于进程权限最小化原则，系统执行任务时一般使用非root的普通用户，该用户需要访问Linux系统中必要的目录和文件，所以对于系统本身运行依赖的系统目录、配置文件、可执行文件、证书文件，相应权限可适当放宽权限控制，建议如下：

| 文件类型                         | 设置值           |
| -------------------------------- | ---------------- |
| 目录                             | 755（rwxr-xr-x） |
| 程序文件（含脚本文件、库文件等） | 755（rwxr-xr-x） |
| 配置文件                         | 644（rw-r--r--） |
| 证书文件（无私钥）               | 444（r--r--r--） |

常见的需要做访问权限控制的文件的建议权限如下：

| 文件名称                         | 设置值           |
| -------------------------------- | ---------------- |
| /etc/passwd                     | 0644（-rw-r--r--） |
| /etc/group                      | 0644（-rw-r--r--） |
| /etc/shadow                      | 0000（----------） |
| /etc/gshadow                      | 0000（----------） |
| /etc/passwd-                      | 0644（-rw-r--r--） |
| /etc/shadow-                      | 0000（----------） |
| /etc/group-                      | 0644（-rw-r--r--） |
| /etc/gshadow-                      | 0000（----------） |
| /etc/ssh/sshd_config               | 0600（-rw-------） |

**规则影响：**

权限配置不能过大，也不能过小，例如有些系统配置文件，如果将权限设置为600或640，那么普通用户就无法读取，相应的程序可能因为无权读取配置而无法执行。

**检查方法：**

使用ll命令或ls -l命令查看文件权限：

```bash
# ls -l test
-rwxr-sr-t. 1 root root 33 Nov  5 14:44 test
```

**修复方法：**

使用chmod命令修改文件权限：

```bash
# chmod 750 test
# ll test
-rwxr-x---. 1 root root 33 Nov  5 14:44 test
```