### 1.1.16 确保软、硬链接文件保护配置正确

**级别：** 要求

**适用版本：** 全部

**规则说明：** 

在Linux系统中，软、硬链接文件是一个文件链接到另一个目标文件，打开该链接文件其实就是打开目标文件。所以，攻击者以低权限用户伪造的软链接文件，可以被高权限用户执行，导致提权安全问题。硬链接文件有同样问题。

本规则要求系统中对软、硬链接进行加固，如果目标文件和链接文件不是同属主的，且链接文件属主无权执行目标文件的，无论访问该链接的用户是谁，均拒绝访问。

这里就会存在一种竞争风险，如果一个高权限进程需要在/tmp目录（一般在全局可写目录下创建的文件容易被利用攻击，因为其他目录权限控制比较严格）创建一个临时文件A，可能的操作是先判断文件是否存在，如果不存在，就创建并打开。此时，攻击者可以在判断之后，创建之前，利用这个时间间隙创建一个同临时文件A同名的软链接文件到系统关键文件B（需要高权限管理员才能访问），此时，高权限进程创建并访问文件A，其实就相当于直接访问了文件B，原本攻击者对文件B没有权限，但利用高权限进程，访问到了文件B，通过该进程，可以对文件B进行破坏、篡改、数据窃取。

可以看到在这个案例中，原本文件A和B的属主应该都是root，但因为存在竞争攻击，A的属主变成了攻击者普通用户，临时文件变成了链接文件，B依旧是root属主，结果只要高权限进程有文件B的权限，就可以通过A这个软链接文件访问B。

openEuler默认已经设置软、硬链接保护。

**规则影响：**

无

**检查方法：**

使用如下命令检查，如果返回值为1，表示已经启用保护：

```bash
# sysctl fs.protected_symlinks
fs.protected_symlinks = 1
# sysctl fs.protected_hardlinks
fs.protected_hardlinks = 1
```

**修复方法：**

openEuler默认已经启用保护，无需设置。

* 如果因实际场景需要启、闭保护状态，可使用如下命令临时设置，重启后恢复默认值：

  启用保护

  ```bash
  # sysctl -w fs.protected_symlinks=1
  fs.protected_symlinks = 1
  # sysctl -w fs.protected_hardlinks=1
  fs.protected_hardlinks = 1
  ```

  关闭保护

  ```bash
  # sysctl -w fs.protected_symlinks=0
  fs.protected_symlinks = 0
  # sysctl -w fs.protected_hardlinks=0
  fs.protected_hardlinks = 0
  ```

* 可以通过修改/etc/sysctl.conf文件，添加如下代码，并执行# sysctl -p /etc/sysctl.conf，实现永久启、闭保护状态：

  启用保护

  ```bash
  # vim /etc/sysctl.conf
  fs.protected_symlinks = 1
  fs.protected_hardlinks = 1
  ```

  关闭保护

  ```bash
  # vim /etc/sysctl.conf
  fs.protected_symlinks = 0
  fs.protected_hardlinks = 0
  ```