### 1.1.5 确保UMASK配置正确

**级别：** 要求

**适用版本：** 全部

**规则说明：** 

UMASK是默认文件或目录权限的掩码，创建文件或目录的时候，以777权限按位减去UMASK的值，如果是文件，则还需要去掉可执行权限，然后得到文件或目录的默认权限设置。UMASK如果设置不合理，可能导致新建文件权限过小或过大，从而影响业务正常运行或导致安全风险。

考虑到社区版本在不同场景下的易用性，openEuler发行版默认不配置UMASK，请根据实际场景按需配置。

**规则影响：**

按规范要求将UMASK配置为077后，创建的文件默认权限为600，目录默认权限为700，会使属组及其他用户使用受限，降低易用性。

**检查方法：**

- 检查配置文件中UMASK值是否正确，可以添加多个目录同时检查，例如下面代码中同时检查了/etc/bashrc和用户home目录下.bashrc文件，获得umask值为077：

  ```
  # grep -i "^umask" /etc/bashrc ~/.bashrc
  /etc/bashrc:umask 0077
  /root/.bashrc:umask 077
  ```

- 使用root用户登录，创建文件或目录，确认权限是否正确：

  ```
  # touch test
  # ll test
  -rw-------. 1 root root 0 Nov  4 17:36 test
  
  # mkdir testdir
  # ll -d testdir
  drwx------. 2 root root 4096 Nov  4 17:36 testdir
  ```

- 使用普通账号test登录，创建文件或目录，确认权限是否正确：

  ```
  $ touch test
  $ ll test
  -rw-------. 1 test test 0 Nov  4 17:37 test
  
  $ mkdir testdir
  $ ll -d testdir
  drwx------. 2 test test 4096 Nov  4 17:37 testdir
  ```

**修复方法：**

可以在两个地方进行修改：

- 在/etc/bashrc文件中对umask字段进行修改，该文件变化对全局所有用户下次登录有影响：

```
# vim /etc/bashrc
umask 0077
```

- 在~/.bashrc文件中对umask字段进行修改或添加，该文件变化只对当前用户下次登录时有影响，如果该文件中的配置同/etc/bashrc不一致，则以该文件为准：

```
$ vim /home/test/.bashrc
umask 0077
```