### 1.2.6 确保yum源配置GPG校验

**级别：** 要求

**适用版本：** 全部

**规则说明：** 

安装包在网络传输或本地存储时存在被攻击者恶意篡改的可能，若未对安装包进行完整性校验，则可能安装了攻击者篡改后的软件，导致服务器甚至整个网络集群遭受攻击。如果使用repo源进行操作系统软件安装升级，必须配置GPG校验。

openEuler支持使用dnf或yum命令从repo源下载、安装或升级rpm包，通过/etc/yum.repo.d目录下的文件进行repo源配置，必须配置GPG校验，在系统中必须已安装GPG公钥，或者在repo源配置文件中指定公钥下载地址。

GPG公钥是校验RPM包合法性的关键，请确保安装可信的GPG公钥。

**规则影响：**

无GPG的repo源无法正常使用。

**检查方法：**

检查系统中是否已经加载GPG公钥，如果返回为空，表示未安装公钥，如果有不同的repo源配置，可能会有多个不同的公钥返回：

```bash
# rpm -qa gpg-pubkey*
gpg-pubkey-e2ec75bc-5c78bcae
```

检查repo源配置文件中是否包含有“gpgcheck=1”字段，如果有多个配置文件，则每个配置文件都应该设置该字段：

```bash
# grep -iE "^gpgcheck[ ]*=[ ]*1" /etc/yum.repos.d/ -rn
/etc/yum.repos.d/base.repo:6:gpgcheck=1
```

检查repo源配置文件中是否已配置公钥下载地址（如果系统中已经安装有对应repo源的公钥，则不是必须配置）：

```bash
# grep -iE "^gpgkey" /etc/yum.repos.d/ -rn
/etc/yum.repos.d/base_tmp.repo:7:gpgkey=<repo源GPG公钥地址>
```

**修复方法：**

openEuler所有商用发布的rpm包都经过GPG私钥签名，通过rpm命令进行安装时会校验签名是否合法，如果校验不通过，可以安装，但会给出告警提示（如下）。禁止通过添加--nosignature --nodigest等方式跳过签名和完整性校验。

```bash
# rpm -ivh keyutils-<version numbers>.rpm
warning: keyutils-<version numbers>.rpm: Header V4 RSA/SHA256 Signature, key ID e2ec75bc: NOKEY
Verifying...            ################################# [100%]
Preparing...            ################################# [100%]
Updating / installing...
   1:keyutils-<version numbers>  ################################# [100%]
```

通过repo源进行rpm包安装时，必须在repo源配置文件中添加gpgcheck=1字段，开启GPG校验，并添加正确的GPG公钥下载地址：

```bash
# vim /etc/yum.repos.d/base.repo
[Euler]
name=Euler
baseurl=<repo源地址>
gpgkey=<repo源GPG公钥地址>
enabled=1
priority=1
gpgcheck=1
```

如果repo配置文件中不包含GPG公钥下载地址，则必须通过rpm命令安装对应源的公钥，如果有多个repo源，则每个repo源可能有不同的GPG公钥，需要分别安装：

```bash
# rpm --import ./key
```