### 2.1.1 禁止无需登录的账号设置登录能力

**级别：** 要求

**适用版本：** 全部

**规则说明：** 

通常情况下，Linux系统中存在多个账号，而这些账号并不一定都是需要登录的，例如systemd、dhcp等软件安装时会自带安装一些账号，这些账号只是为了运行相关的服务进程。对于无需进行登录的账号，必须禁止其登录能力。如果允许非登录账号有登录能力，将扩大攻击面，攻击者可以利用这些账号进行bash交互操作，从而攻击系统。

注意，sync、shutdown、halt属于特殊账号，通常情况下不能将shell设置为nologin或false，这几个账号在/shadow文件中口令设置为“*”，所以并不能直接登录。

openEuler默认满足无需登录的账号不具备登录能力。

**规则影响：**

无

**检查方法：** 

检查的目的是确认是否所有不该登录的账号都被设置了/sbin/nologin或/bin/false，或对应的口令被锁定。

- 使用如下命令查看/etc/passwd文件中非登录账号是否都已经被设置正确，命令执行后会列出所有设置了禁止登录的账号，可根据业务场景对这些账号进行比对：

  ```bash
  # cat /etc/passwd | grep "\/sbin\/nologin\|\/bin\/false" | awk -F ":" '{print $1}'
  ```

- 使用如下命令查看/etc/passwd文件中所有允许登录的账号，命令执行后会列出所有允许登录的账号，可根据业务场景对这些账号进行比对：

  ```bash
  # cat /etc/passwd | grep -v "\/sbin\/nologin\|\/bin\/false" | awk -F ":" '{print $1}'
  ```

- 如下命令执行后会列出所有口令被锁定的账号，可根据业务场景对这些账号进行比对：

  ```bash
  # cat /etc/passwd | awk -F ":" '{print $1}' | xargs -I '{}' passwd -S '{}' | awk '($2=="L" || $2=="LK") {print $1}' 
  ```

- 如下命令执行后会列出所有口令未被锁定的账号，可根据业务场景对这些账号进行比对：

  ```bash
  # cat /etc/passwd | awk -F ":" '{print $1}' | xargs -I '{}' passwd -S '{}' | awk '($2!="L" && $2!="LK") {print $1}'
  ```

**修复方法：** 

有两种方法可以锁定和解锁用户账号：

- 通过usermod命令修改/etc/passwd文件，将指定账号的登录shell设置为/sbin/nologin或/bin/false，该方法不仅可以防止用户登录，还可以防止使用su命令切换为指定用户账号，优先推荐该方法，操作如下（test为账号名）：

  锁定：

  ```bash
  # usermod -s /sbin/nologin test
  ```
  或
  ```bash
  # usermod -s /bin/false test
  ```
  解锁：

  ```bash
  # usermod -s /bin/bash test
  ```

- 修改/etc/shadow文件，在指定账号的第二个字段中添加感叹号“!”或“!!”，锁定口令，可通过如下命令操作（test为账号名，如果账号并未设置口令，则会提示操作失败）：

  锁定：

  ```bash
  # usermod -L test
  ```
  或
  ```bash
  # passwd -l test
  ```
  解锁：

  ```bash
  # usermod -U test
  ```
  或
  ```bash
  # passwd -u test
  ```

  使用usermod命令锁定的口令，可以使用passwd命令进行解锁，反之亦然。锁定或解锁后可以通过如下命令检查状态，LK表示口令已经锁定，NP表示口令未设置，PS表示口令已被设置，且未锁定：

  ```bash
  # passwd -S test
  test LK 2022-01-01 0 30 10 35 (Password locked.)
  ```
  或
  ```bash
  # passwd -S test
  test NP 2020-12-03 0 50 10 35 (Empty password.)
  ```
  或
  ```bash
  # passwd -S test
  test PS 2022-01-01 0 30 10 35 (Password set, SHA512 crypt.)
  ```