### 2.1.3 确保不同账号初始分配不同的组ID

**级别：** 要求

**适用版本：** 全部

**规则说明：** 

不同用户账号的初始登录组必须不同，如果某个用户账号需要访问其他组的文件，则需要通过命令明确指定加入该组。在大多数情况下，文件权限设置为640，文件夹设置为750，那么同组用户账号是可以对文件进行访问的，所以如果两个不相干的用户账号被设置为同一个组，存在文件被意外读取甚至篡改的可能。

openEuler默认满足不同账号初始分配不同的组ID。

**规则影响：**

无

**检查方法：**

检查/etc/passwd文件中各个账号所属的组id是否不同，可执行如下命令，如果没有相同组id，则命令执行后无输出，否则输出组id号以及相同组id的账号数量，如下面例子中输出1003 2，表示有两个账号的用户组id为1003：

```bash
# cat /etc/passwd | awk -F ":" '{a[$4]++}END{for(i in a){if(a[i]!=1 && i!=0){print i, a[i]}}}'
1003 2
```

注意：上面命令中过滤了root用户组，因为sync、shutdown等系统账号都属于root组，属于例外场景，在本规范中不做要求。

**修复方法：**

- 添加新账号时，不使用-g参数指定group，而是让系统直接自动分配新的group组，此处-U参数表示需要创建新用户组，默认可以不加：

  ```bash
  # useradd test
  ```
  或
  ```bash
  # useradd test
  ```
- 如果新账号需要被加入其它组，则可以通过-G参数指定，该命令为test1账号新建一个test1的组，作为test1账号默认登录组，另外会将test1账号加入用户组test：

  ```bash
  # useradd -G test test1
  ```

  通过如下命令检查test1同test的默认登录组不同：

  ```bash
  # cat /etc/passwd | grep test
  test:x:1007:1007::/home/test:/bin/bash
  test1:x:1008:1008::/home/test1:/bin/bash
  ```

  通过如下命令可以看到test1账号同时被加入了test组：

  ```bash
  # id test1
  uid=1008(test1) gid=1008(test1) groups=1008(test1),1007(test)
  ```

  test1账号登录后（或者su切换），可以通过newgrp命令切换到test组，命令执行后当前gid已经变成test组的id了，但这并不会改变/etc/passwd中的组id：

  ```bash
  # su test1
  $ newgrp test
  $ id
  uid=1008(test1) gid=1007(test) groups=1007(test),1008(test1) context=unconfined_u:unconfined_r:unconfined_t:s0-s0:c0.c1023
  ```

- 如果是已有账号，需要加入其他组，则可以通过如下命令操作

  ```bash
  # usermod -a -G root test1
  ```

  执行后，test1账号被加入到root组，查看结果如下：

  ```bash
  # id test1
  uid=1008(test1) gid=1008(test1) groups=1008(test1),0(root),1007(test)
  ```