### 2.1.6 确保账号拥有自己的Home目录

**级别：** 要求

**适用版本：** 全部

**规则说明：** 

每个用户账号必须有自己的Home目录，用来存放账号相关的数据，该目录的属主必须是用户自身。如果Home目录属主不是自身，那么可能无法对该目录进行读写，或者该目录下保存的用户数据可以被其他用户（如属主）读取或篡改。如果没有Home目录，则用户账号登录后将无法获取到自身的环境配置数据。

openEuler默认满足每个账户拥有自己的Home目录。

**规则影响：**

无

**检查方法：**

使用如下脚本进行检查，如果无返回输出，则表示所有用户账号均有Home目录，目录属主正确：

```bash
#!/bin/bash  
 
grep -E -v '^(halt|sync|shutdown)' "/etc/passwd" | awk -F ":" '($7 != "/bin/false" && $7 != "/sbin/nologin" && $7 != "/usr/sbin/nologin") {print $1 " " $6}' | while read name home;
do
    if [ ! -d "$home" ]; then
        echo "No home folder \"$home\" of \"$name\"."
    else
            owner=`ls -l -d $home | awk -F " " '{print $3}'`
        if [ "$owner" != "$name" ]; then
            echo "\"$home\" is owned by $owner, not \"$name\"."
        fi
    fi
done
```

**修复方法：**

- 删除相应的用户账号：

  ```bash
  # userdel -r test
  userdel: test home directory (/home/test) not found
  ```

- 使用useradd命令添加用户账号（同时自动创建Home目录）：

  ```bash
  # useradd test
  # ll -d /home/test/
  drwx------. 2 test test 4096 Feb  2 13:19 /home/test/
  ```