### 2.2.1 确保口令复杂度设置正确

**级别：** 要求

**适用版本：** 全部

**规则说明：** 

口令设置过于简单，容易被猜测，太短的口令、纯数字或纯字母的口令容易被暴力破解工具猜测出来。在系统设置口令时，应强制用户使用复杂口令。对于高安全要求的业务场景，可参考业界最佳实践，比如：口令长度设置为14位或更长，对于四种字符组合，建议每种字符至少出现一次，保证口令不会被轻易破解。

openEuler要求设置口令复杂度如下：

- 口令长度至少8个字符。
- 口令必须包含如下至少3种字符的组合：
  - 至少一个小写字母。
  - 至少一个大写字母。
  - 至少一个数字。
  - 至少一个特殊字符：`~!@#$%^&*()-_=+|[{}];:'",<.>/?和空格。

考虑到在不同场景下的易用性，openEuler默认不配置enforce_for_root和retry值，请根据实际场景按需配置。

**规则影响：**

口令规则太过复杂，又会影响系统的易用性，给用户的正常使用造成不便。所以可以根据实际需求和使用场景，设计符合安全要求的口令复杂度。

**检查方法：**

方法1：
- /etc/pam.d/system-auth和/etc/pam.d/password-auth分别提供该功能项的配置，不同应用程序或者服务对应的配置项，需根据各自include的配置文件而定：

  ```bash
  # grep system-auth /etc/pam.d/ -r
  /etc/pam.d/login:auth       substack     system-auth
  /etc/pam.d/login:account    include      system-auth
  /etc/pam.d/login:password   include      system-auth
  /etc/pam.d/login:session    include      system-auth
  /etc/pam.d/sudo:auth       include      system-auth
  /etc/pam.d/sudo:account    include      system-auth
  /etc/pam.d/sudo:password   include      system-auth
  /etc/pam.d/sudo:session    include      system-auth-su
  ```

  以上只列举部分显示结果，从以上结果可知，login和sudo的账号认证采用/etc/pam.d/system-auth文件中的配置。

  后续以/etc/pam.d/system-auth为例进行说明。

- 在/etc/pam.d/system-auth文件中检查“设置口令复杂度”的配置情况：

  ```bash
  # grep pam_pwquality /etc/pam.d/system-auth
  password    requisite     pam_pwquality.so minlen=8 minclass=3 enforce_for_root try_first_pass local_users_only retry=3 dcredit=0 ucredit=0 lcredit=0 ocredit=0
  ```

方法2：
- 在/etc/security/pwquality.conf文件中检查“设置口令复杂度”的配置情况：

  ```bash
  #cat /etc/security/pwquality.conf
  minlen=8
  minclass=3
  retry=3
  dcredit=0
  ucredit=0
  lcredit=0
  ocredit=0
  enforce_for_root
  ```
  此处仅列举本规范关注的配置项。

**修复方法：**

方法1：
- 口令复杂度的设置可以通过修改/etc/pam.d/password-auth和/etc/pam.d/system-auth文件实现。以/etc/pam.d/system-auth文件为例，具体配置字段如下：
  ```bash
  # vim /etc/pam.d/system-auth
  password    requisite     pam_pwquality.so minlen=8 minclass=3 enforce_for_root try_first_pass local_users_only retry=3 dcredit=0 ucredit=0 lcredit=0 ocredit=0
  ```

方法2：
- 在/etc/security/pwquality.conf文件中配置如下字段：
  ```bash
  # vim /etc/security/pwquality.conf
  minlen=8
  minclass=3
  retry=3
  dcredit=0
  ucredit=0
  lcredit=0
  ocredit=0
  enforce_for_root
  ```

pam_pwquality.so配置项参数字段说明如下表：

| **配置项**       | **说明**                                                     |
| ---------------- | ------------------------------------------------------------ |
| minlen=8         | 口令长度至少包含8个字符。 说明： 建议配置更长的口令最小长度。 |
| minclass=3       | 口令至少包含大写字母、小写字母、数字和特殊字符中的任意3种    |
| ucredit=0        | 口令包含任意个大写字母                                       |
| lcredit=0        | 口令包含任意个小写字母                                       |
| dcredit=0        | 口令包含任意个数字                                           |
| ocredit=0        | 口令包含任意个特殊字符                                       |
| retry=3          | 每次修改最多可以尝试3次                                      |
| enforce_for_root | 本设置对root账号同样有效                                     |