### 2.2.4 确保口令中不包含账号字符串

**级别：** 要求

**适用版本：** 全部

**规则说明：** 

为了用户账号的安全，要求配置“口令中不包含账号字符串”功能。

口令跟账号名字符相同，或者是账号名字符逆序容易被攻击者猜测，而且口令中包含账号名字符，也增加了口令被破译的风险。账号名小于等于3个字符的情况下不作要求，但建议实际场景中设置长度合理的账号名。

账号名大于3个字符时，其口令不能是如下字符：

- 账号名称
- 账号名称逆序
- 包含账号名称字符

**规则影响：**

无法设置包含账号字符串的口令。

**检查方法：**

- /etc/pam.d/system-auth和/etc/pam.d/password-auth分别提供该功能项的配置，不同应用程序或者服务对应的配置项，需根据各自include的配置文件而定：

  ```bash
  # grep system-auth /etc/pam.d/ -r
  /etc/pam.d/login:auth       substack     system-auth
  /etc/pam.d/login:account    include      system-auth
  /etc/pam.d/login:password   include      system-auth
  /etc/pam.d/login:session    include      system-auth
  /etc/pam.d/sudo:auth       include      system-auth
  /etc/pam.d/sudo:account    include      system-auth
  /etc/pam.d/sudo:password   include      system-auth
  /etc/pam.d/sudo:session    include      system-auth-su
  ```

  以上只列举部分显示结果，从以上结果可知，login和sudo的账号认证采用/etc/pam.d/system-auth文件中的配置。

  后续以/etc/pam.d/system-auth为例进行说明。

- 在/etc/pam.d/system-auth文件中检查“口令中不包含账号字符串”的配置情况，不应包含“usercheck=0”字段：

  ```bash
  # grep pam_pwquality /etc/pam.d/system-auth
  password    requisite     pam_pwquality.so minlen=8 minclass=3 enforce_for_root try_first_pass local_users_only retry=3 dcredit=0 ucredit=0 lcredit=0 ocredit=0
  ```

**修复方法：**

pam_pwquality.so是一个执行口令质量检测的pam模块，默认支持“口令中不包含账号字符串”该功能。所以，配置文件中包含该模块，且未配置“usercheck=0”，即可实现对应的功能；反之，则无法实现。

通过修改/etc/pam.d/password-auth和/etc/pam.d/system-auth文件实现。以/etc/pam.d/system-auth文件为例，如果配置中存在“usercheck=0”字段，则删除，具体配置字段如下：

```bash
# vim /etc/pam.d/system-auth
password    requisite     pam_pwquality.so minlen=8 minclass=3 enforce_for_root try_first_pass local_users_only retry=3 dcredit=0 ucredit=0 lcredit=0 ocredit=0
```