### 2.2.6 确保弱口令字典设置正确

**级别：** 要求

**适用版本：** 全部

**规则说明：** 

若用户口令是弱口令，就很容易被攻击者猜测到、或者在较短时间内通过字典攻击法进行破解。弱口令字典是一个包含强度不够、容易被猜测到的口令的集合。弱口令包括：系统默认的口令、过去曾被泄露的口令等。OS提供口令字典检查功能，在创建、修改口令的时候检查，如果命中则禁止使用该口令。弱口令字典可更新、可扩展。可根据实际业务场景，设定适合本业务的弱口令字典。

在升级场景中需要注意：历史版本是否启用了弱口令字典检查，或者新版本是否新增了弱口令清单。

**规则影响：**

原系统中可以使用的口令在新版本中可能被认定为弱口令，导致口令无法设置成功。

**检查方法：**

方法1：
- /etc/pam.d/system-auth和/etc/pam.d/password-auth分别提供该功能项的配置，不同应用程序或者服务对应的配置项，需根据各自include的配置文件而定：

  ```bash
  # grep system-auth /etc/pam.d/ -r
  /etc/pam.d/login:auth       substack     system-auth
  /etc/pam.d/login:account    include      system-auth
  /etc/pam.d/login:password   include      system-auth
  /etc/pam.d/login:session    include      system-auth
  /etc/pam.d/sudo:auth       include      system-auth
  /etc/pam.d/sudo:account    include      system-auth
  /etc/pam.d/sudo:password   include      system-auth
  /etc/pam.d/sudo:session    include      system-auth-su
  ```

  以上只列举部分显示结果，从以上结果可知，login和sudo的账号认证采用/etc/pam.d/system-auth文件中的配置。

  后续以/etc/pam.d/system-auth为例进行说明。

- 在/etc/pam.d/system-auth文件中检查“设置弱口令字典”的配置情况：

  ```bash
  # grep pam_pwquality /etc/pam.d/system-auth
  password    requisite     pam_pwquality.so minlen=8 minclass=3 enforce_for_root try_first_pass local_users_only retry=3 dcredit=0 ucredit=0 lcredit=0 ocredit=0
  ```
  如果没有配置dictcheck=0，则默认为开启，无需手动配置。
- 使用如下命令，导出字典库到文件dictionary.txt中：

  ```bash
  # cracklib-unpacker /usr/share/cracklib/pw_dict > dictionary.txt
  ```

方法2：
- 在/etc/security/pwquality.conf文件中检查“弱口令字典”的配置情况：

  ```bash
  # grep -rnR "dictcheck" /etc/security/pwquality.conf
  ```
  如果没有配置dictcheck=0，则默认开启，无需手动配置。

**修复方法：**

pam_pwquality.so是一个执行口令质量检测的pam模块，默认支持“设置弱口令字典”功能，使用如下操作可以更新弱口令字典库：

- 使用如下命令，导出字典库到文件dictionary.txt中：

  ```bash
  # cracklib-unpacker /usr/share/cracklib/pw_dict > dictionary.txt
  ```

- 将弱口令字典导出并修改后，可执行如下命令进行字典库更新：

  ```bash
  # create-cracklib-dict dictionary.txt
  ```

- 可在原字典库基础上新增其他字典内容，如custom.txt：

  ```bash
  # create-cracklib-dict dictionary.txt custom.txt
  ```