### 2.2.7 确保口令有效期设置正确

**级别：** 要求

**适用版本：** 全部

**规则说明：** 

如果口令长期不修改，则通过暴力破解等方法，容易增加口令被破解的可能性，从而影响系统安全；但该值如果设置过小，则导致口令频繁修改，增加管理成本，且容易导致用户因长时间未登录而无法再次登录，所以在设置该值时需要根据实际业务场景进行判断。

口令需要设置有效期，口令过期后用户重新登录时，提示口令过期，并强制修改，否则无法进入系统。口令最大有效期应为90天或者更短；口令过期前7天或更长时间应开始提示用户修改口令；两次修改口令的最小间隔时间建议设置为7天，可根据业务场景调整。

由于root是最高权限账号，如果长期未登录，导致root口令过期，或者因为频繁修改导致遗忘，系统将无法登录，存在管理风险。建议根据实际业务场景决定是否设置root口令过期时间，对于需要频繁登录root账号的场景，建议设置较短的过期时间；对于日常管理使用非root账号的，建议设置相对较长的过期时间。

考虑到社区版本在不同场景下的易用性，openEuler发行版默认不配置口令有效期和两次修改口令的最小间隔时间，请根据实际场景按需配置。

**规则影响：**

PASS_MAX_DAYS（口令有效期）：设置过长，会降低安全性，增加被暴力破解的概率，设置过短，会增加口令的管理复杂度；

PASS_WARN_AGE（口令过期前提醒）：设置过长，会过早提醒，降低用户体验，设置过短，会导致用户错过修改口令时间；

PASS_MIN_DAYS（两次修改口令的最小间隔时间）：设置过短，用户可以频繁更改口令以规避历史口令防重用检查机制；

**检查方法：**

- 检查/etc/login.defs文件中是否已经配置相关字段：

  ```bash
  # grep ^PASS_MAX_DAYS /etc/login.defs 
  PASS_MAX_DAYS 90
  # grep ^PASS_WARN_AGE /etc/login.defs 
  PASS_WARN_AGE 7
  # grep ^PASS_MIN_DAYS /etc/login.defs
  PASS_MIN_DAYS 0
  ```

- 检查/etc/shadow文件中指定账号的配置是否正确：

  ```bash
  # grep ^test: /etc/shadow 
  test:!:18599:0:90:7:35::  
  ```

**修复方法：**

有两种设置方法：

- 修改/etc/login.defs文件中的默认配置，对后续新建账号口令默认生效：

  ```bash
  # vim /etc/login.defs
  PASS_MAX_DAYS 90
  PASS_MIN_DAYS 0
  PASS_WARN_AGE 7
  ```

- 修改shadow文件中具体某个账号的口令有效期，新增的账号，口令的默认有效期同/etc/login.defs文件中定义一致，对应的值会写到shadow文件中，例如：

  ```bash
  # useradd test
  # cat /etc/shadow | grep test
  test:!:18599:0:90:7:35::
  ```

  shadow文件中每一行记录一个账号的口令信息，通过冒号“:”划分为9个字段，如上举例中：

  - 第4字段表示两次修改口令的最小间隔时间，默认为0，表示不作限制；
  - 第5字段表示口令最大有效期（自设置之日起），默认90天，设置成99999表示永不过期；
  - 第6字段表示口令过期前几天开始提醒，默认7天；
  - 第7个字段表示口令修改有效期，过期后几天内允许用户修改。时间段内，用户登录时强制要求修改口令；超过这个时间，直接拒绝用户登录，默认值是35天。

  管理员可通过passwd命令进行修改。

  设置两次口令修改最小间隔时间：

  ```bash
  # passwd -n 0 test
  Adjusting aging data for user test.
  passwd: Success
  ```

  设置口令最大有效期：

  ```bash
  # passwd -x 90 test
  Adjusting aging data for user test.
  passwd: Success
  ```

  设置口令过期前提醒时间：

  ```bash
  # passwd -w 7 test
  Adjusting aging data for user test.
  passwd: Success
  ```

  设置口令修改有效期（无法通过/etc/login.defs设置默认值）：

  ```bash
  # passwd -i 35 test
  Adjusting aging data for user test.
  passwd: Success 
  ```