### 2.2.9 确保Grub已设置口令保护

**级别：** 要求

**适用版本：** 全部

**规则说明：** 

Grub是Linux的默认引导程序，通过引导程序可以设置系统的启动模式，而设置Grub口令可以防御攻击者通过修改Grub设置进入单用户模式。

如果没有设置Grub口令，攻击者可以轻易进入Grub编辑菜单，通过修改启动参数进行攻击行为，例如：进入单用户模式修改root口令，窃取数据。

UEFI和legacy是两种不同的引导方式，对应的Grub配置文件路径会存在差异。UEFI的配置路径为：/boot/efi/EFI/openEuler，legecy的配置路径为/boot/grub2。

**规则影响：**

需要验证Grub口令后才能进入Grub编辑菜单。

**检查方法：**

UEFI模式下：

方法1：

- 查看grub.cfg配置文件是否存在password_pbkdf2相关配置：

  ```bash
  # grep password_pbkdf2 /boot/efi/EFI/openEuler/grub.cfg
  password_pbkdf2 root ${GRUB2_PASSWORD}
  ```

- GRUB2_PASSWORD是定义在user.cfg文件中的口令密文，“xxxx”表示密文内容：

  ```bash
  # cat /boot/efi/EFI/openEuler/user.cfg
  GRUB2_PASSWORD=grub.pbkdf2.sha512.10000.xxxx
  ```

方法2：

- 查看grub.cfg配置文件是否存在password_pbkdf2相关配置：

  ```bash
  # grep grub.pbkdf2.sha512.10000 /boot/efi/EFI/openEuler/grub.cfg
  grub.pbkdf2.sha512.10000.xxxx
  ```

legecy模式下：

方法1：

- 查看grub.cfg配置文件是否存在password_pbkdf2相关配置：

  ```bash
  # grep password_pbkdf2 /boot/grub2/grub.cfg
  password_pbkdf2 root ${GRUB2_PASSWORD}
  ```

- GRUB2_PASSWORD是定义在user.cfg文件中的口令密文，“xxxx”表示密文内容：

  ```bash
  # cat /boot/grub2/user.cfg
  GRUB2_PASSWORD=grub.pbkdf2.sha512.10000.xxxx
  ```

方法2：

- 查看grub.cfg配置文件是否存在password_pbkdf2相关配置：

  ```bash
  # grep grub.pbkdf2.sha512.10000 /boot/grub2/grub.cfg
  grub.pbkdf2.sha512.10000.xxxx
  ```

**修复方法：**

- openEuler在安装阶段通过人工方式在图形界面设置Grub2口令。

- 建议用户首次登录时修改口令并定期更新，避免口令泄露后，启动选项被篡改，导致系统启动异常。

  在终端输入grub2-mkpasswd-pbkdf2后，根据提示输入明文口令后，生成sha512加密的口令密文，“xxxx”表示密文内容：

  ```bash
  # grub2-mkpasswd-pbkdf2
  Enter password: 
  Reenter password: 
  PBKDF2 hash of your password is 
  grub.pbkdf2.sha512.10000.xxxx
  ```

  UEFI模式下，将新口令密文输出到/boot/efi/EFI/openEuler/user.cfg文件中：

  ```bash
  # echo "GRUB2_PASSWORD=grub.pbkdf2.sha512.10000.xxxx" > /boot/efi/EFI/openEuler/user.cfg
  ```

  legecy模式下，将新口令密文输出到/boot/grub2/user.cfg文件中：

  ```bash
  # echo "GRUB2_PASSWORD=grub.pbkdf2.sha512.10000.xxxx" > /boot/grub2/user.cfg
  ```

- 系统下次重启时，如果需要进入Grub2菜单，将需要验证新口令。