### 2.4.9 避免root用户本地接入系统

**级别：** 建议

**适用版本：** 全部

**规则说明：** 

root是Linux系统中的超级特权用户，具有所有Linux系统资源的访问权限。如果允许直接使用root账号登录Linux系统对系统进行操作，会带来很多潜在的安全风险，为了规避由此带来的风险，应禁止直接使用root帐号登录操作系统，仅在必要的情况通过其他技术手段（如：sudo或su）间接的使用root账号。

由于root账号拥有最高权限，直接使用root登录存在如下风险：

* 高危误操作可能直接导致服务器瘫痪，例如误删除、修改系统关键文件；

* 如果有多人需要root权限操作，则root口令将有多人保管，容易导致口令泄露，同时增加了口令维护成本。

openEuler默认不进行配置，如果实际场景中不存在需要使用root账号在本地登录的情况，建议禁用root账号本地登录。

**规则影响：**

root账号无法本地接入系统。

**检查方法：**

* 检查/etc/pam.d/system-auth文件中是否添加了account类型的pam_access.so模块，且该模块必须在sufficient控制行之前加载：

  ```bash
  # cat /etc/pam.d/system-auth
  account     required      pam_unix.so
  account     required      pam_faillock.so
  account     sufficient    pam_localuser.so
  account     sufficient    pam_succeed_if.so uid < 1000 quiet
  ```

* 并且，检查/etc/security/access.conf文件中是否设置对root用户登录tty1的限制：

  ```bash
  # grep "^\-:root" /etc/security/access.conf
  ```

* 使用串口尝试登录root账号，确认是否拒绝登录。如果拒绝登录，串口打印信息如下：

  ```bash
  Authorized users only. All activities may be monitored and reported.
  localhost login: root
  Password:
  
  Permission denied 
  ```

**修复方法：**

* 在/etc/pam.d/system-auth文件中添加了account类型的pam_access.so模块，且该模块必须在sufficient控制行之前加载：

  ```bash
  # vim /etc/pam.d/system-auth
  …
  account     required      pam_unix.so
  account     required      pam_faillock.so
  account     required      pam_access.so
  account     sufficient     pam_localuser.so
  …
  ```

* 在/etc/security/access.conf文件中添加对root用户登录tty1的限制：

  ```bash
  # vim /etc/security/access.conf
  -:root:tty1
  ```