### 2.5.1 应当启用IMA度量

**级别：** 建议

**适用版本：** 全部

**规则说明：** 

IMA（Integrity Measurement Architecture）完整性度量架构是内核提供的完整性保护功能，开启IMA时，可基于用户自定义的策略为系统中的重要文件提供完整性度量，度量结果可被用于本地以及远程完整性证明。

系统未开启IMA度量功能时，无法实时记录关键文件的摘要信息，不能识别对文件内容或属性的篡改。本地证明、远程证明等保护系统完整性的功能依赖于IMA度量提供的摘要值，因此也无法使用，或者完整性保护不全。

IMA全局策略配置与具体环境相关，通常情况下完整性保护只针对于不可变文件（如可执行文件、动态库等），如果策略配置不当，可能导致性能及内存开销过大，建议用户根据自身情况决定是否开启IMA，并配置正确的策略。

注意：由于IMA只是全局完整性保护机制中的度量部分，要完整使用需依赖TPM 2.0及远程证明服务，本规范仅对IMA度量部分进行说明、建议。如果系统未集成TPM 2.0及远程证明服务，则不应启用IMA度量功能。

IMA度量不支持容器环境和虚拟机环境，且要求UEFI启动，不支持Legacy模式。

**规则影响：**

* 开启IMA度量会导致系统启动时间和文件访问时间有轻微增加。
* 如果策略配置不当（如对实时变化的日志文件、临时文件等进行度量），可导致度量日志增长过快、占用系统内存过大，且度量日志所占用内存在系统下次重启前不会被释放，进而影响业务正常运行。另外由于被度量文件一直在变化，引发度量值变化，而远程证明基线值无法同步更新，导致远程证明失败，失去完整性保护的意义。

**检查方法：**

* 首先确认当前内核启动参数中是否配置了integrity=1，如果查不到该参数，则说明IMA没有开启：

  ```bash
  # cat /proc/cmdline | grep integrity=1
  BOOT_IMAGE=/vmlinuz-<kernel version> root=/dev/mapper/openeuler-root ro resume=/dev/mapper/openeuler-swap rd.lvm.lv=openeuler/root rd.lvm.lv=openeuler/swap crashkernel=512M quiet  integrity=1
  ```

* 确认IMA开启后，查看/sys/kernel/security/ima/runtime_measurement_count文件中存储的度量记录数，如果该值大于1，则表示已配置IMA度量策略：

  ```bash
  # cat /sys/kernel/security/ima/runtime_measurements_count
  2053
  ```

**修复方法：**

* 在/boot/efi/EFI/openEuler/grub.cfg文件中配置启动参数“integrity=1 ima_appraise=off evm=ignore”（其中后两个参数可不配置），并重启系统：

  ```bash
  # vim /boot/efi/EFI/openEuler/grub.cfg
          linuxefi   /vmlinuz-<kernel version> root=/dev/mapper/openeuler-root ro resume=dev/mapper/openeuler-swap rd.lvm.lv=openeuler/root rd.lvm.lv=openeuler/swap crashkernel=512M integrity=1 ima_appraise=off evm=ignore
  ```

* 配置度量策略，一共有两种方式：

  在/etc/ima目录下添加策略文件ima-policy，该方式比较灵活，可以在ima-policy文件中自定义各自策略：

  ```bash
  # vim /etc/ima/ima-policy
  <ima policy lines>
  ```

  在启动参数中配置ima_policy=<tcb/exec_tcb>，该方式使用系统默认的几种策略（默认策略度量文件范围大，请谨慎使用），并重启系统：

  ```bash
  # vim /boot/efi/EFI/openEuler/grub.cfg
          linuxefi   /vmlinuz-<kernel version> root=/dev/mapper/openeuler-root ro resume=dev/mapper/openeuler-swap rd.lvm.lv=openeuler/root rd.lvm.lv=openeuler/swap crashkernel=512M integrity=1 ima_policy=tcb
  ```