### 3.1.1 避免使用不常见网络服务

**级别：** 建议

**适用版本：** 全部

**规则说明：** 

一些不常见的协议，往往使用场景较少，社区发展较慢，安全问题不易被快速解决，如果未关闭这些并不使用的协议，可能导致攻击者利用协议或代码漏洞进行攻击。

流控制传输协议（SCTP，Stream Control Transmission Protocol）是一种在网络连接两端之间同时传输多个数据流的协议，SCTP提供的服务与UDP和TCP类似。

透明进程间通信（TIPC，Transparent Inter-process Communication）是一种用于进程间通信的网络通信协议，原本是为集群间通信特别设计的。它允许设计人员能够创建可以和其它应用快速可靠通信的应用，无须考虑其它需要通信的应用在集群环境中的位置。

如果业务场景不需要使用SCTP和TIPC等服务，要求从内核中关闭支持，减小攻击场景。

**规则影响：**

无

**检查方法：**

- 使用modprobe命令检查sctp，如果输出“install /bin/true”，表示sctp已经被禁止使用；如果输出“insmod /lib/modules/(kernel version)/kernel/net/sctp/sctp.ko”，表示未被禁止，并列出ko所在目录；如果输出“modprobe: FATAL: Module sctp not found in directory /lib/modules/(kernel version)”，表示不存在该ko文件，可不用处理：

  ```bash
  # modprobe -n -v sctp
  install /bin/true 
  ```

- 使用modprobe命令检查tipc，如果输出“install /bin/true”，表示tipc已经被禁止使用；如果输出“insmod /lib/modules/(kernel version)/kernel/net/tipc/tipc.ko”，表示未被禁止，并列出ko所在目录，根据平台不同，即使已经禁用tipc，命令执行后也可能会列出tipc的依赖ko，如udp_tunnel.ko和ip6_udp_tunnel.ko，可不用处理；如果输出“modprobe: FATAL: Module tipc not found in directory /lib/modules/(kernel version)”，表示不存在该ko文件，可不用处理：

  ```bash
  # modprobe -n -v tipc
  insmod /lib/modules/(kernel version)/kernel/net/ipv4/udp_tunnel.ko 
  insmod /lib/modules/(kernel version)/kernel/net/ipv6/ip6_udp_tunnel.ko
  install /bin/true
  ```

**修复方法：**

在/etc/modprobe.d/目录下，添加一个任意文件名，并以.conf为后缀的配置文件，属主和属组均为root, 权限600，按照如下格式填入内容，即可禁用sctp和tipc协议：

```bash
# vim /etc/modprobe.d/test.conf
install sctp /bin/true
install tipc /bin/true
```