### 3.2.10 应当正确配置iptables INPUT、OUTPUT关联策略

**级别：** 建议

**适用版本：** 全部

**规则说明：**

虽然可以通过配置协议、ip和端口等，将进出服务器的报文策略配置到INPUT和OUTPUT链，但有些情况下会比较复杂，比如客户端通过某端口访问服务器，但服务器在返回响应报文时并不一定从原端口返回，可能使用随机的源端口，这种情况下通过sport参数很难配置准确的策略。

此时需要考虑使用关联链接的方式配置策略，如果一个外发的报文属于一个已经存在的网络链接，则直接放行；如果一个接收的报文，属于一个已经存在的网络链接，也直接放行。因为这些已经存在的链接必定是经过其他策略过滤和检查的，否则无法建立。

如果不通过关联链接的方式配置策略，则需要将所有可能的链接情况全部分析清楚并配置对应的策略，如果配置过松，可能导致安全风险，如果配置过严，可能导致业务中断。

**规则影响**：

无

**检查方法：**

检查INPUT和OUTPUT链是否配置了关联策略：

```bash
# iptables -L
Chain INPUT (policy DROP)
target     prot opt source               destination
ACCEPT     tcp  --  anywhere             anywhere             state ESTABLISHED
ACCEPT     udp  --  anywhere             anywhere             state ESTABLISHED
ACCEPT     icmp --  anywhere             anywhere             state ESTABLISHED

Chain FORWARD (policy DROP)
target     prot opt source               destination

Chain OUTPUT (policy DROP)
ACCEPT     tcp  --  anywhere             anywhere             state NEW,ESTABLISHED
ACCEPT     udp  --  anywhere             anywhere             state NEW,ESTABLISHED
ACCEPT     icmp --  anywhere             anywhere             state NEW,ESTABLISHED
```

检查IPv6：

```bash
# ip6tables -L
Chain INPUT (policy DROP)
target     prot opt source               destination
ACCEPT     all      anywhere             anywhere
DROP       all      localhost            anywhere
ACCEPT     tcp      anywhere             anywhere             tcp dpt:ssh
ACCEPT     tcp      anywhere             anywhere             state ESTABLISHED
ACCEPT     udp      anywhere             anywhere             state ESTABLISHED
ACCEPT     icmp     anywhere             anywhere             state ESTABLISHED

Chain FORWARD (policy DROP)
target     prot opt source               destination

Chain OUTPUT (policy DROP)
target     prot opt source               destination
ACCEPT     all      anywhere             anywhere
ACCEPT     tcp      anywhere             anywhere             tcp spt:ssh
ACCEPT     tcp      anywhere             anywhere             state NEW,ESTABLISHED
ACCEPT     udp      anywhere             anywhere             state NEW,ESTABLISHED
ACCEPT     icmp     anywhere             anywhere             state NEW,ESTABLISHED
```

**修复方法：**

通过如下命令配置OUTPUT链的tcp、udp和icmp策略，允许所有新建和已建立链接的报文外发；配置INPUT链的tcp、udp和icmp策略，允许所有已建立链接的报文接收：

```bash
# iptables -A OUTPUT -p tcp -m state --state NEW,ESTABLISHED -j ACCEPT
# iptables -A OUTPUT -p udp -m state --state NEW,ESTABLISHED -j ACCEPT
# iptables -A OUTPUT -p icmp -m state --state NEW,ESTABLISHED -j ACCEPT
# iptables -A INPUT -p tcp -m state --state ESTABLISHED -j ACCEPT
# iptables -A INPUT -p udp -m state --state ESTABLISHED -j ACCEPT
# iptables -A INPUT -p icmp -m state --state ESTABLISHED -j ACCEPT
```

通过如下命令使当前配置的策略永久生效：

```bash
# service iptables save
iptables: Saving firewall rules to /etc/sysconfig/iptables: [  OK  ]
```

配置IPv6：

```bash
# ip6tables -A OUTPUT -p tcp -m state --state NEW,ESTABLISHED -j ACCEPT
# ip6tables -A OUTPUT -p udp -m state --state NEW,ESTABLISHED -j ACCEPT
# ip6tables -A OUTPUT -p icmp -m state --state NEW,ESTABLISHED -j ACCEPT
# ip6tables -A INPUT -p tcp -m state --state ESTABLISHED -j ACCEPT
# ip6tables -A INPUT -p udp -m state --state ESTABLISHED -j ACCEPT
# ip6tables -A INPUT -p icmp -m state --state ESTABLISHED -j ACCEPT
```

通过如下命令使当前配置的策略永久生效：

```bash
# service ip6tables save
ip6tables: Saving firewall rules to /etc/sysconfig/ip6tables: [  OK  ]
```