### 3.2.12 应当配置nftables默认拒绝策略

**级别：** 建议

**适用版本：** 全部

**规则说明：**

从安全角度考虑，nftables基础链类似于iptables，（input、output、forward）需要配置所有报文的拒绝策略，然后再在基础链中添加允许策略，开放相关服务和端口。

如果没有配置基础链，或没有指定基础链的hook规则，报文将不会被nftables捕捉到，也就无法进行过滤处理。

**规则影响：**

如果基础链未配置DROP或REJECT策略，报文默认都将被ACCEPT，容易因为遗漏拒绝策略而导致安全风险。

**检查方法：**

通过如下方法检查是否配置了input、output和forward的DROP策略，注意举例中同时已经配置了SSH的input和output ACCEPT策略，如果不配置，通过SSH远程登录将断开：

```bash
# nft list ruleset
table inet test {
	chain input {
		type filter hook input priority 0; policy drop;
		tcp dport ssh accept
	}

	chain output {
		type filter hook output priority 0; policy drop;
		tcp sport ssh accept
	}

	chain forward {
		type filter hook forward priority 0; policy drop;
	}
}
```

**修复方法：**

首先创建table：

```bash
# nft add table inet <table name>
```

然后通过如下方法在table中配置input、output、forward基础链的drop策略，注意，配置后网络将可能断开：

```bash
# nft add chain inet <table name> <chain name> { type filter hook input priority 0\; policy drop\; }
# nft add chain inet <table name> <chain name> { type filter hook output priority 0\; policy drop\; }
# nft add chain inet <table name> <chain name> { type filter hook forward priority 0\; policy drop\; }
```

通过如下方式将当前配置的规则保存到配置文件中，以便系统重启后能够自动加载：

```bash
# nft list ruleset > /etc/sysconfig/nftables.conf
```

注意，上述方式保存配置文件会覆盖原有配置内容，亦可将当前规则导出到单独文件中，或者直接在文件中编写新规则，然后在/etc/sysconfig/nftables.conf配置文件中通过include方式加载，此种方式需要注意避免多个include规则文件内有重复规则：

```bash
# nft list ruleset > /etc/nftables/new_test_rules.nft
# echo "include \"/etc/nftables/new_test_rules.nft\"" >> /etc/sysconfig/nftables.conf
```