### 3.2.13 应当配置nftables loopback策略

**级别：** 建议

**适用版本：** 全部

**规则说明：**

回环地址是服务器上一个特殊的地址，以127.0.0.0/8表示，同网卡无关，主要用于本机进程间通信，不应该从网卡上收到源地址为127.0.0.0/8的报文，此类报文应该被丢弃。如果回环地址策略设置不正确，则可能导致本机进程间通信失败，或者从网卡收到欺骗报文。

服务器需要设置策略，允许接收和处理lo接口的回环地址报文，但拒绝从网卡收到的报文。

**规则影响：**

无

**检查方法：**

查看是否已经配置回环地址策略，input链需要配置从“lo”设备接收报文的ACCEPT策略，配置从非“lo”设备接收，且源地址为127.0.0.0/8的报文的DROP策略，在output链需要配置源地址为127.0.0.0/8的报文的ACCEPT策略：

IPv4配置：

```bash
# nft list ruleset
table inet test {
	chain input {
		type filter hook input priority 0; policy drop;
		tcp dport ssh accept
		iif "lo" accept
		iif != "lo" ip saddr 127.0.0.0/8 drop
	}

	chain output {
		type filter hook output priority 0; policy drop;
		tcp sport ssh accept
		ip saddr 127.0.0.0/8 accept
	}

	chain forward {
		type filter hook forward priority 0; policy drop;
	}
}
```

IPv6配置：

```bash
# nft list ruleset
table inet test {
	chain input {
		type filter hook input priority 0; policy drop;
		tcp dport ssh accept
		iif "lo" accept
		iif != "lo" ip6 saddr ::1 drop
	}

	chain output {
		type filter hook output priority 0; policy drop;
		tcp sport ssh accept
		ip6 saddr ::1 accept
	}

	chain forward {
		type filter hook forward priority 0; policy drop;
	}
}
```

**修复方法：**

通过如下方法添加input和output链的策略：

配置input链“lo”接口ACCEPT策略：

```bash
# nft add rule inet test input iif "lo" accept
```

配置IPv4 input链DROP策略，output链ACCEPT策略：

```bash
# nft add rule inet test input iif != "lo" ip saddr 127.0.0.0/8 drop
# nft add rule inet test output ip saddr 127.0.0.0/8 accept
```

配置IPv6 input链DROP策略，output链ACCEPT策略：

```bash
# nft add rule inet test input iif != "lo" ip6 saddr ::1 drop
# nft add rule inet test output ip6 saddr ::1 accept
```

通过如下方式将当前配置的规则保存到配置文件中，以便系统重启后能够自动加载：

```bash
# nft list ruleset > /etc/sysconfig/nftables.conf
```

注意，上述方式保存配置文件会覆盖原有配置内容，亦可将当前规则导出到单独文件中，或者直接在文件中编写新规则，然后在/etc/sysconfig/nftables.conf配置文件中通过include方式加载，此种方式需要注意避免多个include规则文件内有重复规则：

```bash
# nft list ruleset > /etc/nftables/new_test_rules.nft
# echo "include \"/etc/nftables/new_test_rules.nft\"" >> /etc/sysconfig/nftables.conf
```