### 3.2.16 应当正确配置nftables input、output关联策略

**级别：** 建议

**适用版本：** 全部

**规则说明：**

虽然可以通过配置协议、ip和端口等，将进出服务器的报文策略配置到input和output链，但有些情况下会比较复杂，比如客户端通过某端口访问服务器，但服务器在返回响应报文时并不一定从原端口返回，可能使用随机的源端口，这种情况下通过sport参数很难配置准确的策略。

此时需要考虑使用关联链接的方式配置策略，如果一个外发的报文属于一个已经存在的网络链接，则直接放行；如果一个接收的报文，属于一个已经存在的网络链接，也直接放行。因为这些已经存在的链接必定是经过其他策略过滤和检查的，否则无法建立。

如果不通过关联链接的方式配置策略，则需要将所有可能的链接情况全部分析清楚并配置对应的策略，如果配置过松，可能导致安全风险，如果配置过严，可能导致业务中断。

**规则影响**：

无

**检查方法：**

检查input和output链是否配置了关联策略：

```bash
# nft list ruleset
table inet test {
	chain input {
		type filter hook input priority 0; policy drop;
		tcp dport ssh accept
		ip protocol tcp ct state established accept
		ip protocol udp ct state established accept
		ip protocol icmp ct state established accept
	}

	chain output {
		type filter hook output priority 0; policy drop;		
		ip protocol tcp ct state established,related,new accept
		ip protocol udp ct state established,related,new accept
		ip protocol icmp ct state established,related,new accept
	}

	chain forward {
		type filter hook forward priority 0; policy drop;
	}
}
```

**修复方法：**

通过如下命令配置output链的tcp、udp和icmp策略，允许所有新建和已建立链接的报文外发；配置input链的tcp、udp和icmp策略，允许所有已建立链接的报文接收：

```bash
# nft add rule inet test output ip protocol tcp ct state new,related,established accept
# nft add rule inet test output ip protocol udp ct state new,related,established accept
# nft add rule inet test output ip protocol icmp ct state new,related,established accept
# nft add rule inet test input ip protocol tcp ct state established accept
# nft add rule inet test input ip protocol udp ct state established accept
# nft add rule inet test input ip protocol icmp ct state established accept
```

通过如下方式将当前配置的规则保存到配置文件中，以便系统重启后能够自动加载：

```bash
# nft list ruleset > /etc/sysconfig/nftables.conf
```

注意，上述方式保存配置文件会覆盖原有配置内容，亦可将当前规则导出到单独文件中，或者直接在文件中编写新规则，然后在/etc/sysconfig/nftables.conf配置文件中通过include方式加载，此种方式需要注意避免多个include规则文件内有重复规则：

```bash
# nft list ruleset > /etc/nftables/new_test_rules.nft
# echo "include \"/etc/nftables/new_test_rules.nft\"" >> /etc/sysconfig/nftables.conf
```
