### 3.2.6 应当正确配置iptables默认拒绝策略

**级别：** 建议

**适用版本：** 全部

**规则说明：**

通常情况下，iptables策略配置可以分为白名单方式和黑名单方式两种，建议通过白名单方式配置，只要不符合白名单中规则的链接，全部禁止。所以可以先配置对INPUT、OUTPUT、FORWARD链的DROP或REJECT策略，然后针对需要开放的端口和服务配置ACCEPT策略。

**规则影响：**

通过黑名单方式配置策略，由于未被配置为DROP或REJECT的链接都将被ACCEPT，容易因为遗漏而导致安全风险。

**检查方法：**

使用如下命令检查IPv4的INPUT、OUTPUT、FORWARD链默认是否为拒绝策略：

```bash
# iptables -L | grep -E "INPUT|OUTPUT|FORWARD"
Chain INPUT (policy DROP)
Chain FORWARD (policy DROP)
Chain OUTPUT (policy DROP)
```

使用如下命令检查IPv6的INPUT、OUTPUT、FORWARD链默认是否为拒绝策略：

```bash
# ip6tables -L | grep -E "INPUT|OUTPUT|FORWARD"
Chain INPUT (policy DROP)
Chain FORWARD (policy DROP)
Chain OUTPUT (policy DROP)
```

**修复方法：**

使用如下命令配置INPUT、OUTPUT、FORWARD链的默认策略为拒绝。需要注意的是，如果通过网络连接进行远程配置操作，那么策略被修改后网络就会断开，需要通过串口进行连接配置：

```bash
# iptables -A INPUT -j DROP
# iptables -A OUTPUT -j DROP
# iptables -A FORWARD -j DROP
```

通过如下命令使当前配置的策略永久生效：

```bash
# service iptables save
iptables: Saving firewall rules to /etc/sysconfig/iptables: [  OK  ]
```

配置IPv6默认策略：

```bash
# ip6tables -A INPUT -j DROP
# ip6tables -A OUTPUT -j DROP
# ip6tables -A FORWARD -j DROP
```

通过如下命令使当前配置的策略永久生效：

```bash
# service ip6tables save
ip6tables: Saving firewall rules to /etc/sysconfig/ip6tables: [  OK  ]
```