### 3.2.7 应当正确配置iptables loopback策略

**级别：** 建议

**适用版本：** 全部

**规则说明：**

回环地址是服务器上一个特殊的地址，以127.0.0.0/8表示，同网卡无关，主要用于本机进程间通信，不应该从网卡上收到源地址为127.0.0.0/8的报文，此类报文应该被丢弃。如果回环地址策略设置不正确，则可能导致本机进程间通信失败，或者从网卡收到欺骗报文。

服务器需要设置策略，允许接收和处理lo接口的回环地址报文，但拒绝从网卡收到的报文。

**规则影响：**

无

**检查方法：**

查看IPv4的INPUT、OUTPUT链是否已经正确配置回环地址策略：

```bash
# iptables -L INPUT -v -n
Chain INPUT (policy DROP 389 packets, 125K bytes)
 pkts bytes target     prot opt in     out     source               destination
 1089 81354 ACCEPT     tcp  --  *      *       0.0.0.0/0            0.0.0.0/0            tcp dpt:22
   10   840 ACCEPT     all  --  lo     *       0.0.0.0/0            0.0.0.0/0
    0     0 DROP       all  --  *      *       127.0.0.0/8          0.0.0.0/0
# iptables -L OUTPUT -v -n
Chain OUTPUT (policy DROP 58 packets, 11780 bytes)
 pkts bytes target     prot opt in     out     source               destination
  871 94717 ACCEPT     tcp  --  *      *       0.0.0.0/0            0.0.0.0/0            tcp spt:22
   17  1428 ACCEPT     all  --  *      lo      0.0.0.0/0            0.0.0.0/0
```

查看IPv6的INPUT、OUTPUT链是否已经正确配置回环地址策略：

```bash
# ip6tables -L INPUT -v -n
Chain INPUT (policy DROP 0 packets, 0 bytes)
 pkts bytes target     prot opt in     out     source               destination
    0     0 ACCEPT     all      lo     *       ::/0                 ::/0
    0     0 DROP       all      *      *       ::1                  ::/0
# ip6tables -L OUTPUT -v -n
Chain OUTPUT (policy DROP 0 packets, 0 bytes)
 pkts bytes target     prot opt in     out     source               destination
    0     0 ACCEPT     all      *      lo      ::/0                 ::/0
```

**修复方法：**

通过如下命令设置允许接收和处理lo接口报文，拒绝源地址为127.0.0.0/8的报文。iptables是按照顺序进行规则匹配的，所以DROP规则必须被添加在另外两条规则之后，否则由于lo接口发出的报文源地址也是127.0.0.0/8，会被DROP规则丢弃：

```bash
# iptables -A INPUT -i lo -j ACCEPT
# iptables -A OUTPUT -o lo -j ACCEPT
# iptables -A INPUT -s 127.0.0.0/8 -j DROP
```

通过如下命令使当前配置的策略永久生效：

```bash
# service iptables save
iptables: Saving firewall rules to /etc/sysconfig/iptables: [  OK  ]
```

配置IPv6：

```bash
# ip6tables -A INPUT -i lo -j ACCEPT
# ip6tables -A OUTPUT -o lo -j ACCEPT
# ip6tables -A INPUT -s ::1 -j DROP
```

通过如下命令使当前配置的策略永久生效：

```bash
# service ip6tables save
ip6tables: Saving firewall rules to /etc/sysconfig/ip6tables: [  OK  ]
```