### 3.3.2 确保SSH服务认证方式配置正确

**级别：** 要求

**适用版本：** 全部

**规则说明：** 

配置合理的认证方式有利于确保用户及系统数据安全，通常情况下，对于人机账号，账号/口令方式比较合适；对于非交互式的登录场景，公私钥方式比较合适；而对于高安全风险场景，仅开启公私钥认证方式更合适。如果使用基于主机的身份认证，攻击者可通过域名污染或IP欺骗后无需口令直接入侵系统。

SSH服务本身提供多种认证方式，但出于安全考虑，禁止使用基于主机的身份认证。

openEuler默认使用账号/口令方式认证，在安装系统时，要求配置root管理员口令。

openEuler允许公私钥方式认证。

openEuler允许交互式-账号/口令方式认证。

根据业务场景需要，务必配置正确的认证方式。

**规则影响：**

无

**检查方法：**

通过如下方法，检查配置是否正确，此处IgnoreRhosts必须配置为yes，HostbasedAuthentication必须配置为no，PasswordAuthentication、ChallengeResponseAuthentication和PubkeyAuthentication至少有一个为yes：

```bash
# grep "^PasswordAuthentication\|^PubkeyAuthentication\|^ChallengeResponseAuthentication\|^IgnoreRhosts\|^HostbasedAuthentication" /etc/ssh/sshd_config
PasswordAuthentication yes
PubkeyAuthentication yes
ChallengeResponseAuthentication yes
IgnoreRhosts yes
HostbasedAuthentication no
```

**修复方法：**

- 启用账号/口令认证方式

  配置/etc/ssh/sshd_config文件，开启PasswordAuthentication选项，重启sshd服务，如下：

  ```bash
  # vim /etc/ssh/sshd_config
  PasswordAuthentication yes
  # systemctl restart sshd
  ```

- 启用公私钥认证方式

  配置/etc/ssh/sshd_config文件，开启PubkeyAuthentication选项，并配置公钥存储路径，重启sshd服务，例如：

  ```bash
  # vim /etc/ssh/sshd_config
  PubkeyAuthentication yes
  AuthorizedKeysFile      .ssh/authorized_keys
  # systemctl restart sshd
  ```

  客户端生成RSA公私钥，并把公钥拷贝到指定目录下即可，如上例中“.ssh/authorized_keys”目录。

- 启用交互式-账号/口令认证方式

  配置/etc/ssh/sshd_config文件，开启ChallengeResponseAuthentication选项，重启sshd服务，如下：

  ```bash
  # vim /etc/ssh/sshd_config
  ChallengeResponseAuthentication yes
  # systemctl restart sshd
  ```

- 关闭基于主机的认证

  配置/etc/ssh/sshd_config文件，开启IgnoreRhosts，关闭HostbasedAuthentication，重启sshd服务，如下：

  ```bash
  # vim /etc/ssh/sshd_config
  IgnoreRhosts yes
  HostbasedAuthentication no
  # systemctl restart sshd
  ```