### 3.5.20 确保core dump配置正确

**级别：** 要求

**适用版本：** 全部

**规则说明：** 

Core dump是当程序运行过程中异常终止或崩溃时，把内存状态记录下来的行为，有助于事后定位，但可能会包含进程内存里的敏感信息。有时用户需要开启core dump功能记录当时产生问题的原因，对于需要开启core dump功能的用户需对日志输入的路径进行限制，同时需限制路径只允许特定用户访问。

启用core dump有助于程序异常终止或崩溃的事后定位，但容易泄露内存中的敏感信息。openEuler默认打开，用户需要根据业务场景，关闭core dump或对日志输入的路径和访问用户进行限制。

**规则影响：**

关闭core dump后，程序异常时缺少日志记录，不利于问题定位。

**检查方法：**

* 禁用场景的检查方法：

  输入以下命令并检查相应的命令返回：

  ```bash
  # ulimit -c
  0
  ```

  或者检查文件/etc/security/limits.conf，是否包含配置行“* hard core 0”。

* 限制场景的检查方法：

  执行以下脚本成功返回（无内容输出），表示已限制了core dump目录：
  
  ```bash
  #!/bin/bash  
  core_path=$(sysctl kernel.core_pattern | awk -F"^[[:space:]]*kernel.core_pattern[[:space:]]*=[[:space:]]*" '{print $2}')
  [[ "${core_path}" =~ ^/.+ ]] || { echo "kernel.core_pattern[${core_path}] must be started with /"; exit 1; }
  core_dir=$(dirname "${core_path}")
  [[ -d "${core_dir}" ]] || { echo "kernel.core_pattern dir[${core_dir}] not exist"; exit 1; }
  rights_digit=$(stat -c%a "${core_dir}")
  [[ "${rights_digit}" =~ ^700$ || "${rights_digit}" =~ ^1770$ || "${rights_digit}" =~ ^1777$ ]] || { echo "rights[${rights_digit}] of dir[${core_dir}] not safe, must be 700 or 1770 or 1777"; exit 1; }
  exit 0
  ```

**修复方法：**

* 禁用方法

  使用如下命令对当前会话禁止系统支持生成core dump
  ```bash
  # ulimit -c 0
  ```

  修改/etc/security/limits.conf文件，添加或修改配置，使其永久生效
  ```bash
  * hard core 0
  ```

* 限制使用方法：
  1、ulimit -c不为0，比如：
  
    ```bash
    # ulimit -c 10485760
    ```
    
  2、设置core dump日志文件保存位置和文件格式
    通过修改/proc/sys/kernel/core_pattern可以控制core dump日志文件保存位置和文件格式。
    下例为将所有的core dump日志文件生成到/corefiles目录下（绝对路径），文件名的格式为core-命令名-pid-时间戳：
    
    ```bash
    # sysctl "kernel.core_pattern=/corefiles/core-%e-%p-%t"
    ```
    
    修改/etc/sysctl.conf文件，添加或修改配置
    ```bash
    kernel.core_pattern=/corefiles/core-%e-%p-%t
    ```
  
    建议为/corefiles建立独立分区，禁止/corefiles目录占用系统分区或业务分区，避免因为core dump日志文件过多导致分区满而影响系统运行或业务运行。
  
  3、限制目录访问权限：
    可根据业务需要限制目录的访问用户范围。
    a、限制单个用户（比如admin）访问
    
    ```bash
    # chown admin /corefiles
    # chmod 700 /corefiles
    ```
    
    b、使用粘滞位保护技术，限制同组用户（比如core_group）访问
  
    ```bash
    # chown root:core_group /corefiles
    # chmod 1770 /corefiles
    ```
    
    c、使用粘滞位保护技术，限制所有用户访问：
  
    ```bash
    # chown root:root /corefiles
    # chmod 1777 /corefiles
    ```
    
    注：粘滞位对目录的作用，使得目录下A用户不能访问B用户的文件，除非B用户的文件权限允许A用户访问。
    
  4、建议禁止setuid的应用支持生成core dump：
    使用如下命令对当前运行系统禁止setuid的应用支持生成core dump
    ```bash
    # sysctl -w "fs.suid_dumpable=0"
    ```
    
    修改/etc/sysctl.conf文件，添加或修改配置，使其永久生效
    ```bash
    fs.suid_dumpable=0
    ```