### 3.5.7 禁止接收ICMP重定向报文

**级别：** 要求

**适用版本：** 全部

**规则说明：**

ICMP重定向消息是传递路由信息并告诉系统通过备用路径发送数据包。这是一种允许外部路由设备更新系统路由表的方法。通过将net.ipv4.conf.all.accept_redirects和net.ipv6.conf.all.accept_redirects设置为0，系统不会接受任何ICMP重定向报文。通过将net.ipv4.conf.all.secure_redirects和net.ipv4.conf.default.send_redirects设置为0，系统不会从网关接收ICMP重定向报文（IPv6无此配置项）。

攻击者可以利用伪造的ICMP重定向消息恶意更改系统路由表，使它们向错误的网络发送数据包，从而获取相应的敏感数据。

**规则影响：**

系统不接收ICMP重定向报文。

**检查方法：**

首先，检查当前系统内核参数的设置。输入命令查看返回值是否为0：

```bash
# sysctl net.ipv4.conf.all.accept_redirects && sysctl net.ipv6.conf.all.accept_redirects && sysctl net.ipv4.conf.all.secure_redirects && sysctl net.ipv4.conf.default.secure_redirects
net.ipv4.conf.all.accept_redirects = 0
net.ipv6.conf.all.accept_redirects = 0
net.ipv4.conf.all.secure_redirects = 0
net.ipv4.conf.default.secure_redirects = 0
```

其次，执行如下命令，如果返回值不为0，表示配置不正确，建议修改配置文件内容。如果返回值为空，表示系统使用默认配置(值为0)。

```bash
# grep "net.ipv4.conf.all.accept_redirects" /etc/sysctl.conf /etc/sysctl.d/*
net.ipv4.conf.all.accept_redirects=0
# grep "net.ipv6.conf.all.accept_redirects" /etc/sysctl.conf /etc/sysctl.d/*
net.ipv6.conf.all.accept_redirects=0
# grep "net.ipv4.conf.all.secure_redirects" /etc/sysctl.conf /etc/sysctl.d/*
/etc/sysctl.conf:net.ipv4.conf.all.secure_redirects=0
/etc/sysctl.d/99-sysctl.conf:net.ipv4.conf.all.secure_redirects=0
# grep "net.ipv4.conf.default.secure_redirects" /etc/sysctl.conf /etc/sysctl.d/*
/etc/sysctl.conf:net.ipv4.conf.default.secure_redirects=0
/etc/sysctl.d/99-sysctl.conf:net.ipv4.conf.default.secure_redirects=0
```

**修复方法：**

输入命令禁止接收ICMP重定向报文：

```bash
# sysctl -w net.ipv4.conf.all.accept_redirects=0
# sysctl -w net.ipv6.conf.all.accept_redirects=0
# sysctl -w net.ipv4.conf.all.secure_redirects=0
# sysctl -w net.ipv4.conf.default.secure_redirects=0
```

修改/etc/sysctl.conf文件，添加或修改配置：

```bash
net.ipv4.conf.all.accept_redirects=0
net.ipv6.conf.all.accept_redirects=0
net.ipv4.conf.all.secure_redirects=0
net.ipv4.conf.default.secure_redirects=0
```