### 3.6.1 应当正确配置ntpd服务

**级别：** 建议

**适用版本：** 全部

**规则说明：** 

集群场景下，服务器时间是否准确、是否一致比较关键。例如当时间不一致时，可能会导致不同服务器间产生的数据，在根据时间进行排序或比较时，产生的结果不准确。

即使我们在初始时使用date命令把所有服务器时间配置成一致的，随着时间的推移，服务器的时间还是会出现不准确、不一致。所以为保证环境中所有机器的时间同步且准确，必须有一个可以同步的时间服务器，网络内的其他服务器都向该服务器进行时间同步。

当使用ntpd服务实现时间同步时，如果没有正确配置ntpd服务，则服务器时间可能不准确，导致不同服务器间的时间可能不一致。

服务器时间不准确时，对于类似财务、订单等时间敏感的数据会有很大问题。例如因为时间不准确可能导致一笔记账数据落在了错误的财务周期，从而导致资产负债表期末余额不平。

服务器之间的时间不一致时，每个主机产生的报文的时间就存在偏差，如果多个服务器间数据流存在一定处理顺序，后一个环节的服务器时间小于前一个服务器的时间时，可能会导致收到的报文因为时间大于本地时间而丢弃。

**规则影响：**

无

**检查方法：**

- 检查ntpd服务是否启动，Active字段返回“active (running)”表示服务已经启动，返回“inactive (dead)”表示未启动：

  ```bash
  # service ntpd status 2>&1 | grep Active
     Active: inactive (dead)
  ```

- 通过grep命令查看/etc/ntp.conf中restrict的配置，获取ntp权限控制配置：

  ```bash
  # grep "^restrict" /etc/ntp.conf 
  restrict default nomodify notrap nopeer noquery
  ```

- 通过grep命令查看/etc/ntp.conf中server|pool的配置（<IP or domain name>表示具体的服务器IP或域名），获取ntp服务器配置：

  ```bash
  # grep -E "^(server|pool)" /etc/ntp.conf
  server <IP or domain name> iburst
  ```

**修复方法：**

- 将本机配置为时间源，在/etc/ntp.conf文件中增加ntp权限控制配置：

  ```bash
  # vim /etc/ntp.conf 
  restrict <IP or netmask_IP> <parameter>
  ```

  - IP or netmask_IP：权限控制的IP地址，可以是default表示所有IP；可以是不带mask的某一个具体IP地址，例如“192.168.1.2”；也可以是IP+mask表示某一段IP地址，例如“192.168.0.0 mask 255.255.255.0”，表示192.168.0.1至192.168.0.154的所有地址的服务器都可以连接本服务器获取ntp服务。
  - Parameter：权限控制的具体参数。

  例如：restrict default nomodify notrap nopeer noquery，表示允许所有IP地址的服务器与本机时间源进行时间同步，但不允许在此系统上查询或修改服务。

- 本机作为客户端，配置时间源服务器（remote-server为远端时间源服务器地址），在/etc/ntp.conf文件中增加配置：

  ```bash
  # vim /etc/ntp.conf 
  server <remote-server>
  ```

- 在进行前两项配置后（可以同时配置，既作为客户端从远端服务器获取授时，也作为服务端，给其他服务器授时），使用service ntpd restart命令重启ntpd服务：

  ```bash
  # service ntpd restart
  ```