### 4.1.12 应当正确配置硬盘空间阈值

**级别：** 建议

**适用版本：** 全部

**规则说明：** 

在auditd记录日志过程中，如果硬盘空间被写满，可能导致业务无法正常执行，所以需要提前设置相关配置项，确保硬盘在即将写满或已经写满的情况下不至于引起更加严重的系统问题。

配置文件/etc/audit/auditd.conf的如下相关项openEuler已配置默认值，用户可根据业务场景修改：

| 配置项                  | 默认值  | 说明                                                         |
| ----------------------- | ------- | ------------------------------------------------------------ |
| space_left              | 75      | 配置硬盘空间下限告警动作阈值，如低于75MB，则触发space_left_action定义的告警动作 |
| space_left_action       | SYSLOG  | 硬盘空间低于space_left时，触发告警事件，可选：IGNORE、SYSLOG、EMAIL、SUSPEND、SINGLE、HALT。  openEuler默认设置为SYSLOG，表示不会阻止继续记录日志，但会通过syslog记录一次告警。 |
| admin_space_left        | 50      | 配置硬盘空间下限管理动作阈值，如低于50MB，则触发admin_space_left_action定义的操作动作，admin_space_left设置值不能大于space_left的值。 |
| admin_space_left_action | SUSPEND | 硬盘空间低于admin_space_left时，触发管理事件，可选：IGNORE、SYSLOG、EMAIL、SUSPEND、SINGLE、HALT。  openEuler默认设置为SUSPEND，表示auditd服务停止向硬盘输出日志记录。 |
| disk_full_action        | SUSPEND | 表示如果系统检测到硬盘已经写满，则触发处理动作，可选：IGNORE、SYSLOG、SUSPEND、SINGLE、HALT。  openEuler默认设置为SUSPEND，表示auditd服务停止向硬盘输出日志记录。 |
| disk_error_action       | SUSPEND | 表示如果在记录audit日志时，检测到硬盘错误，则触发处理动作，可选：IGNORE、SYSLOG、SUSPEND、SINGLE、HALT。  openEuler默认设置为SUSPEND，表示auditd服务停止向硬盘输出日志记录。 |

如果告警阈值和管理阈值配置过大，则可能硬盘还有较大空间时audit日志就无法正常输出，如果配置过小，则会因为日志输出而将硬盘空间耗尽，影响正常业务，所以建议一方用户根据实际场景配置合理值，另一方面建议将日志输出到单独分区，避免日志过大影响业务。

**规则影响：**

无

**检查方法：**

通过如下方法检查/etc/audit/auditd.conf文件是否配置正确：

```bash
# cat /etc/audit/auditd.conf | grep -iE "space_left|space_left_action|admin_space_left|admin_space_left_action|disk_full_action|disk_error_action"
space_left = 75
space_left_action = SYSLOG
admin_space_left = 50
admin_space_left_action = SUSPEND
disk_full_action = SUSPEND
disk_error_action = SUSPEND
```

**修复方法：**

修改/etc/audit/auditd.conf文件，配置对应字段内容：

```bash
# vim /etc/audit/auditd.conf
space_left = <numeric value in megabytes>
space_left_action = <action>
admin_space_left = <numeric value in megabytes>
admin_space_left_action = <action>
disk_full_action = <action>
disk_error_action = <action>
```

重启auditd服务，使配置生效：

```bash
# service auditd restart
Stopping logging: [  OK  ]
Redirecting start to /bin/systemctl start auditd.service
```