### 4.1.15 应当配置时间修改审计规则

**级别：** 建议

**适用版本：** 全部

**规则说明：** 

系统时间是否准确，影响着业务的正常运行。除了通过时间同步服务器确保时间同步之外，还需要关注管理员通过手工命令方式修改系统时间，后者往往伴随着攻击风险，如攻击者通过修改系统时间使某些保护策略失效（例如口令过期），达成攻击目的。

建议通过审计系统调用（adjtimex、settimeofday、clock_settime），对系统时间修改进行日志记录，同时对/etc/localtime文件进行审计，记录时区变更日志。如果不配置时间修改审计，管理员无法从audit日志中追溯时间变更事件。

openEuler默认不配置时间修改审计规则，建议用户根据实际业务场景配置相应规则。

**规则影响：**

配置时间变更审计，由于在文件操作或系统调用时需要记录审计日志，对性能有轻微影响，但由于时间变更动作本身不应快速、频繁发生，用户无感知。

**检查方法：**

如果是32位系统，通过如下命令检查配置：

```bash
# auditctl -l | grep -iE "adjtimex|settimeofday|clock_settime|localtime"
-a always,exit -F arch=b32 -S stime,settimeofday,adjtimex,clock_settime -F key=time
-w /etc/localtime -p wa -k time
```
如果是64位系统，还需有如下配置：

```bash
-a always,exit -F arch=b64 -S settimeofday,adjtimex,clock_settime -F key=time
```

**修复方法：**

如果是32位系统，在/etc/audit/rules.d/目录下新建规则文件，例如time.rules，在文件中添加审计规则：

```bash
# vim /etc/audit/rules.d/time.rules
-a always,exit -F arch=b32 -S stime -S settimeofday -S adjtimex -S clock_settime -k <rules name>
-w /etc/localtime -p wa -k <rules name>
```
如果是64位系统，需要再添加arch=b64相关配置：
```bash
-a always,exit -F arch=b64 -S settimeofday -S adjtimex -S clock_settime -k <rules name>
```
考虑兼容性，64位系统中arch=b32相关配置必须保留。

重启auditd服务，使规则生效：

```bash
# service auditd restart
Stopping logging: [  OK  ]
Redirecting start to /bin/systemctl start auditd.service
```