### 4.1.17 应当配置网络环境审计规则

**级别：** 建议

**适用版本：** 全部

**规则说明：** 

攻击者可能通过修改系统域名、主机名等实施攻击行为，比如主机欺骗等，建议用户通过设置对系统调用setdomainname、sethostname的审计，以及文件/etc/hosts的审计，监控系统域名、主机名的修改；通过设置对/etc/issue、/etc/issue.net文件的审计，监控登录提示信息的修改。

如果不配置相关审计，如果发生非法修改，不利于追溯。

openEuler默认不配置网络环境审计规则，建议用户根据实际业务场景配置相应规则。

**规则影响：**

配置审计，由于在文件操作时需要记录审计日志，对性能有轻微影响，但由于域名、主机名以及登录提示信息不应被频繁修改，实际对用户无感知。

**检查方法：**

如果是32位系统，通过如下命令检查配置：

```bash
# auditctl -l | grep -iE "setdomainname|sethostname|hosts|issue"
-a always,exit -F arch=b32 -S sethostname,setdomainname -F key=hostnet
-w /etc/hosts -p wa -k hostnet
-w /etc/issue -p wa -k hostnet
-w /etc/issue.net -p wa -k hostnet
```

如果是64位系统，还需有如下配置：
```bash
-a always,exit -F arch=b64 -S sethostname,setdomainname -F key=hostnet
```

**修复方法：**

如果是32位系统，在/etc/audit/rules.d/目录下新建规则文件，例如hostnet.rules，在文件中添加审计规则：

```bash
# vim /etc/audit/rules.d/hostnet.rules
-a always,exit -F arch=b32 -S setdomainname -S sethostname -k <rules name>
-w /etc/hosts -p wa -k <rules name>
-w /etc/issue -p wa -k <rules name>
-w /etc/issue.net -p wa -k <rules name>
```
如果是64位系统，需要再添加arch=b64相关配置：
```bash
-a always,exit -F arch=b64 -S setdomainname -S sethostname -k <rules name>
```
考虑兼容性，64位系统中arch=b32相关配置必须保留。

重启auditd服务，使规则生效：

```bash
# service auditd restart
Stopping logging: [  OK  ]
Redirecting start to /bin/systemctl start auditd.service
```