### 4.1.18 应当配置文件访问控制权限审计规则

**级别：** 建议

**适用版本：** 全部

**规则说明：** 

文件访问权限控制是Linux中基础的权限管理，不同用户被授权可以访问不同的文件，防止用户之间敏感信息泄露或文件数据被篡改，也可以防止普通用户越权访问系统高权限文件或配置。

建议对操作系统中修改文件权限、文件属主的系统调用进行审计监控。如果不配置相关审计，如果发生非法修改，不利于追溯。

openEuler默认不配置文件访问控制权限审计规则，建议用户根据实际业务场景配置相应规则。

**规则影响：**

配置审计，由于在文件权限、属主修改时需要记录审计日志，对性能有轻微影响，但由于此类操作不应被频繁执行，实际对用户无感知。

**检查方法：**

如果是32位系统，通过如下命令检查配置：

```bash
# auditctl -l | grep -iE "chmod|chown|setxattr|exattr"
-a always,exit -F arch=b32 -S chmod,fchmod,fchmodat -F auid>=1000 -F auid!=-1 -F key=fileperm
-a always,exit -F arch=b32 -S chown,fchown,lchown,fchownat -F auid>=1000 -F auid!=-1 -F key=fileperm
-a always,exit -F arch=b32 -S setxattr,lsetxattr,fsetxattr,removexattr,lremovexattr,fremovexattr -F auid>=1000 -F auid!=-1 -F key=fileperm
```
如果是64位系统，还需有如下配置：

```bash
-a always,exit -F arch=b64 -S chmod,fchmod,fchmodat -F auid>=1000 -F auid!=-1 -F key=fileperm
-a always,exit -F arch=b64 -S chown,fchown,lchown,fchownat -F auid>=1000 -F auid!=-1 -F key=fileperm
-a always,exit -F arch=b64 -S setxattr,lsetxattr,fsetxattr,removexattr,lremovexattr,fremovexattr -F auid>=1000 -F auid!=-1 -F key=fileperm
```

**修复方法：**

如果是32位系统，在/etc/audit/rules.d/目录下新建规则文件，例如fileperm.rules，在文件中添加审计规则，此处\<min uid\>是/etc/login.defs文件中UID_MIN（UID_MIN为通过useradd方式添加用户，用户uid的最小值），openEuler上默认是1000：

```bash
# vim /etc/audit/rules.d/fileperm.rules
-a always,exit -F arch=b32 -S chmod -S fchmod -S fchmodat -F auid>=<min uid> -F auid!=unset -k <rules name>
-a always,exit -F arch=b32 -S chown -S fchown -S fchownat -S lchown -F auid>=<min uid> -F auid!=unset -k <rules name>
-a always,exit -F arch=b32 -S setxattr -S lsetxattr -S fsetxattr -S removexattr -S lremovexattr -S fremovexattr -F auid>=<min uid> -F auid!=unset -k <rules name>
```
如果是64位系统，需要再添加arch=b64相关配置：
```bash
-a always,exit -F arch=b64 -S chmod -S fchmod -S fchmodat -F auid>=<min uid> -F auid!=unset -k <rules name>
-a always,exit -F arch=b64 -S chown -S fchown -S fchownat -S lchown -F auid>=<min uid> -F auid!=unset -k <rules name>
-a always,exit -F arch=b64 -S setxattr -S lsetxattr -S fsetxattr -S removexattr -S lremovexattr -S fremovexattr -F auid>=<min uid> -F auid!=unset -k <rules name>
```
考虑兼容性，64位系统中arch=b32相关配置必须保留。
重启auditd服务，使规则生效：

```bash
# service auditd restart
Stopping logging: [  OK  ]
Redirecting start to /bin/systemctl start auditd.service
```