### 4.1.19 应当配置文件访问失败审计规则

**级别：** 建议

**适用版本：** 全部

**规则说明：** 

通过对open、truncate、ftruncate、create、openat等系统调用进行审计监控，如果这些系统调用返回“-EACCES”或“-EPERM”错误，则表示文件无权访问，需要记录审计日志。由于权限问题导致文件访问失败的场景，在攻击行为中比较常见，建议配置审计规则，以便事后追溯。

openEuler默认不配置文件访问失败审计规则，建议用户根据实际业务场景配置相应规则。

**规则影响：**

配置审计，由于在文件访问失败时需要进行审计日志记录，对性能有轻微影响，但在实际场景中，文件访问失败的场景较少，影响有限。

**检查方法：**

如果是32位系统，通过如下命令检查配置：

```bash
# auditctl -l | grep -iE "EACCES|EPERM"
-a always,exit -F arch=b32 -S open,truncate,ftruncate,creat,openat -F exit=-EACCES -F auid>=1000 -F auid!=-1 -F key=fileaccess
-a always,exit -F arch=b32 -S open,truncate,ftruncate,creat,openat -F exit=-EPERM -F auid>=1000 -F auid!=-1 -F key=fileaccess
```
如果是64位系统，还需有如下配置：

```bash
-a always,exit -F arch=b64 -S open,truncate,ftruncate,creat,openat -F exit=-EACCES -F auid>=1000 -F auid!=-1 -F key=fileaccess
-a always,exit -F arch=b64 -S open,truncate,ftruncate,creat,openat -F exit=-EPERM -F auid>=1000 -F auid!=-1 -F key=fileaccess
```

**修复方法：**

如果是32位系统，在/etc/audit/rules.d/目录下新建规则文件，例如fileaccess.rules，在文件中添加审计规则，此处\<min uid>是/etc/login.defs文件中UID_MIN的值，openEuler上默认是1000：

```bash
# vim /etc/audit/rules.d/fileaccess.rules
-a always,exit -F arch=b32 -S creat -S open -S openat -S truncate -S ftruncate -F exit=-EACCES -F auid>=<min uid> -F auid!=unset -k <rules name>
-a always,exit -F arch=b32 -S creat -S open -S openat -S truncate -S ftruncate -F exit=-EPERM -F auid>=<min uid> -F auid!=unset -k <rules name>
```
如果是64位系统，需要再添加arch=b64相关配置：
```bash
-a always,exit -F arch=b64 -S creat -S open -S openat -S truncate -S ftruncate -F exit=-EACCES -F auid>=<min uid> -F auid!=unset -k <rules name>
-a always,exit -F arch=b64 -S creat -S open -S openat -S truncate -S ftruncate -F exit=-EPERM -F auid>=<min uid> -F auid!=unset -k <rules name>
```
考虑兼容性，64位系统中arch=b32相关配置必须保留。
重启auditd服务，使规则生效：

```bash
# service auditd restart
Stopping logging: [  OK  ]
Redirecting start to /bin/systemctl start auditd.service
```