### 4.1.5 应当配置提权命令审计规则

**级别：** 建议

**适用版本：** 全部

**规则说明：** 

普通用户通过调用提权命令（设置了SUID/SGID）可以获得超级管理员权限，所以提权命令的使用具有较高风险，往往被攻击者利用用于对系统进行攻击行为。

建议对提权命令进行审计监控，以便事后追溯。

openEuler默认不配置提权命令审计规则，建议用户根据实际业务场景配置相应规则。

**规则影响：**

配置审计，由于在使用提权命令时需要进行审计日志记录，对性能有轻微影响，如果用户业务存在大量、频繁调用提权命令的场景，则可能存在累积效果。

**检查方法：**

使用如下脚本检查提权命令的审计规则：

```bash
#!/bin/bash

array=`find / -xdev -type f \( -perm -4000 -o -perm -2000 \) | awk '{print $1}'`

for element in ${array[@]}
do
    ret=`auditctl -l | grep "$element "`
    if [ $? -ne 0 ]; then
        echo "$element not set"
    else
        echo $ret
    fi
done
```

如果系统中提权命令已经配置audit策略，则该脚本执行后打印出对应策略行，如果未配置，则打印出“\<file path> not set”字样，如下：

```bash
# sh check.sh
/root/test.sh not set
-a always,exit -S all -F path=/usr/bin/write -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/bin/gpasswd -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/bin/passwd -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/bin/pkexec -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/bin/crontab -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/bin/newgrp -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/bin/chage -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/bin/fusermount -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/bin/at -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/bin/newgidmap -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/bin/wall -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/bin/umount -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/bin/sudo -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/bin/newuidmap -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/bin/mount -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/bin/su -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/libexec/openssh/ssh-keysign -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/libexec/dbus-1/dbus-daemon-launch-helper -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/libexec/utempter/utempter -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/lib/polkit-1/polkit-agent-helper-1 -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/sbin/pam_timestamp_check -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/sbin/grub2-set-bootflag -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/sbin/mount.nfs -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
-a always,exit -S all -F path=/usr/sbin/unix_chkpwd -F perm=x -F auid>=1000 -F auid!=-1 -F key=privileged
```

**修复方法：**

通过如下方法，查找系统中所有可提权（SUID/SGID）命令，并按照配置格式输出到/etc/audit/rules.d/privileged.rules文件中，此处\<min uid>是/etc/login.defs文件中UID_MIN的值，openEuler上可设置为1000：

```bash
# find / -xdev -type f \( -perm -4000 -o -perm -2000 \) | awk '{print "-a always,exit -F path=" $1 " -F perm=x -F auid>=<min uid> -F auid!=unset -k <rules name>" }' > /etc/audit/rules.d/privileged.rules
```

重启auditd服务，使规则生效：

```bash
# service auditd restart
Stopping logging: [  OK  ]
Redirecting start to /bin/systemctl start auditd.service
```