### 4.1.6 应当配置内核模块变更审计规则

**级别：** 建议

**适用版本：** 全部

**规则说明：** 

通常情况下，业务部署完成后，内核模块挂载已经固定，不会变更。如果发生变更，可能存在攻击行为，建议对内核模块变更进行审计监控，事后也可进行追溯。

openEuler默认不配置内核模块变更审计规则，建议用户根据实际业务场景配置相应规则。

**规则影响：**

配置审计，由于在内核模块挂载、卸载时需要进行审计日志记录，对性能有轻微影响，但内核模块挂载、卸载相关操作应不频繁，实际对用户无感知。

**检查方法：**

如果是32位系统，通过如下命令检查内核模块变更的审计规则：

```bash
# auditctl -l | grep -iE "insmod|rmmod|modprobe|init_module|delete_module"
-w /sbin/insmod -p x -k module
-w /sbin/rmmod -p x -k module
-w /sbin/modprobe -p x -k module
-a always,exit -F arch=b32 -S init_module,delete_module -F key=module
```
如果是64位系统，还需有如下配置：

```bash
-a always,exit -F arch=b64 -S init_module,delete_module -F key=module
```

**修复方法：**

如果是32位系统，在/etc/audit/rules.d/目录下新建规则文件，例如module.rules，在文件中添加审计规则：

```bash
# vim /etc/audit/rules.d/module.rules
-w /sbin/insmod -p x -k <rules name>
-w /sbin/rmmod -p x -k <rules name>
-w /sbin/modprobe -p x -k <rules name>
-a always,exit -F arch=b32 -S init_module -S delete_module -k <rules name>

```
如果是64位系统，需要再添加arch=b64相关配置：
```bash
-a always,exit -F arch=b64 -S init_module -S delete_module -k <rules name>
```
考虑兼容性，64位系统中arch=b32相关配置必须保留。 

重启auditd服务，使规则生效：

```bash
# service auditd restart
Stopping logging: [  OK  ]
Redirecting start to /bin/systemctl start auditd.service
```
