### 4.1.9 应当正确配置audit_backlog_limit

**级别：** 建议

**适用版本：** 全部

**规则说明：** 

audit_backlog_limit用于限制audit事件在发往auditd服务进行处理之前在内核中的缓存队列的大小，该值默认为64，如果队列满，则开始丢弃audit事件，并打印告警日志，提示队列满。如果该值配置过小，则可能导致audit事件丢失。

如果在操作系统启动阶段已经配置了启用auditd，则建议将audit_backlog_limit适当配置为较大值，因为内核启动过程中auditd服务尚未启动，此时所有事件都是通过队列缓存的。

openEuler默认不配置，建议用户根据实际场景，设置audit_backlog_limit参数的大小。

**规则影响：**

无

**检查方法：**

执行如下命令，查看内核启动参数中是否已经添加“audit_backlog_limit=\<size\>”：

```bash
# cat /proc/cmdline | grep "audit_backlog_limit"
BOOT_IMAGE=/vmlinuz-<kernel version> root=/dev/mapper/openeuler-root ro resume=/dev/mapper/openeuler-swap rd.lvm.lv=openeuler/root rd.lvm.lv=openeuler/swap crashkernel=512M quiet audit=1 audit_backlog_limit=8192
```

**修复方法：**

* 修改grub.cfg文件，直接在对应内核启动参数后面添加，需要注意的是，grub.cfg文件所在目录根据系统安装配置会有不同，大部分情况存在于/boot/grub2/或/boot/efi/EFI/openEuler/目录下：

  ```bash
  # vim /boot/grub2/grub.cfg
  linuxefi	/vmlinuz-<kernel version> root=/dev/mapper/openeuler-root ro resume=/dev/mapper/openeuler-swap rd.lvm.lv=openeuler/root rd.lvm.lv=openeuler/swap crashkernel=512M quiet audit=1 audit_backlog_limit=<size>
  ```

* 或者修改配置文件/etc/default/grub，在GRUB_CMDLINE_LINUX字段添加“audit_backlog_limit=\<size>”，然后重新生成grub.cfg文件：

  ```bash
  # /etc/default/grub
  GRUB_CMDLINE_LINUX="/dev/mapper/openeuler-swap rd.lvm=openeuler/root rd.lvm.lv=openeuler/swap crashkernel quiet audit=1 audit_backlog_limit=<size>"
  
  # grub2-mkconfig -o /boot/grub2/grub.cfg
  ```

* 修改后重启系统生效：

  ```bash
  # reboot
  ```