### 4.2.7 确保Rsyslog日志rotate已配置

**级别：** 要求

**适用版本：** 全部

**规则说明：** 

rsyslog负责从系统中收集日志记录到文件中，logrotate负责定期或定量对日志文件进行拷贝、压缩，以确保不会因为日志文件过大而导致占用过多的硬盘资源，甚至日志文件不可维护。

如果不配置rotate策略，日志文件会一直增长，最终可能导致日志所在硬盘分区空间耗尽，轻则影响日志记录，重则可能导致系统和业务无法继续正常执行。

openEuler默认已经在/etc/logrotate.d/rsyslog文件中配置rsyslog的rotate策略如下：

* rotate日志文件

  /var/log/cron

  /var/log/maillog

  /var/log/messages

  /var/log/secure

  /var/log/spooler

* 日志文件最大保留期限365天；

* 日志文件最多保留30个；

* 日志文件采用压缩方式保留；

* 日志文件达到4MB，进行rotate操作。

**规则影响：**

无

**检查方法：**

检查/etc/logrotate.d/rsyslog文件中是否已经配置相关字段，此处“/var/log/*”是/etc/rsyslog.conf文件中配置的rsyslog日志输出路径，两者需要匹配一致：

```bash
# cat /etc/logrotate.d/rsyslog | grep -iE "\/var\/log|maxage|\<rotate\>|compress|size"
/var/log/cron
/var/log/maillog
/var/log/messages
/var/log/secure
/var/log/spooler
    maxage 365
    rotate 30
    compress
    size +4096k
```

**修复方法：**

在/etc/logrotate.d目录下创建配置文件，比如/etc/logrotate.d/rsyslog文件，检查并新增如下设置，其中\<log file paths>是/etc/rsyslog.conf文件中配置的rsyslog日志输出路径，两者需要匹配一致：

```bash
# vim /etc/logrotate.d/rsyslog
<log file paths>
{
    maxage <days>
    rotate <files counts>
    notifempty
    compress
    copytruncate
    missingok
    size +<numeric value in kilobyte>k
    sharedscripts
    postrotate
        /bin/kill -HUP `cat /var/run/rsyslogd.pid 2> /dev/null` 2> /dev/null || true
    endscript
}
```