### 4.2.9 应当仅在指定的日志主机上接受远程rsyslog消息

**级别：** 建议

**适用版本：** 全部

**规则说明：** 

默认情况下，rsyslog不会监听来自远程系统的日志消息。rsyslog需加载imtcp.so模块才能通过TCP监听，同理需要加载imudp.so模块才能通过UDP监听，两者都需要指定监听的TCP/UDP端口。确保只在指定的日志主机上接收远程rsyslog消息，以便管理员集中管理，但需要确保日志服务器有足够的硬盘空间用于存储组网环境下所有服务器上报的日志。

**规则影响：**

无

**检查方法：**

运行如下命令检查/etc/rsyslog.conf及/etc/rsyslog.d/*.conf配置文件：

* 检查TCP配置：

  ```bash
  # grep ^\$ModLoad /etc/rsyslog.conf /etc/rsyslog.d/*.conf | grep imtcp
  /etc/rsyslog.conf:$ModLoad imtcp
  # grep ^\$InputTCPServerRun /etc/rsyslog.conf /etc/rsyslog.d/*.conf
  /etc/rsyslog.conf:$InputTCPServerRun 11514
  ```

* 检查UDP配置：

  ```bash
  # grep ^\$ModLoad /etc/rsyslog.conf /etc/rsyslog.d/*.conf | grep imudp
  /etc/rsyslog.conf:$ModLoad imudp
  # grep ^\$InputUDPServerRun /etc/rsyslog.conf /etc/rsyslog.d/*.conf
  /etc/rsyslog.conf:$InputUDPServerRun 11514
  ```

**修复方法：**

修改/etc/rsyslog.conf或/etc/rsyslog.d/*.conf，配置接受远程rsyslog消息，并根据客户端IP单独存放在不同目录，可以自定义指定目录：

* 修复TCP配置：

  ```bash
  # vim /etc/rsyslog.conf
  $ModLoad imtcp
  $InputTCPServerRun 11514
  $template Remote, "/var/log/syslog/%fromhost-ip%/%$YEAR%-%$MONTH%-%$DAY%.log"
  ```

* 修复UDP配置：

  ```bash
  # vim /etc/rsyslog.conf
  $ModLoad imudp
  $InputUDPServerRun 11514
  $template Remote, "/var/log/syslog/%fromhost-ip%/%$YEAR%-%$MONTH%-%$DAY%.log"
  ```

执行如下命令，重启服务，使配置生效

```bash
# systemctl restart rsyslog.service
```